@@ -135,6 +135,7 @@ namespace Lum {
 #if defined(__WIN32__) || defined(WIN32)
       SystemTime(const FILETIME& time);
 #endif
+      virtual ~SystemTime();
 
       SystemTime& operator=(const SystemTime& systemTime);
 
@@ -150,9 +151,10 @@ namespace Lum {
       int GetDaysOfCurrentMonth() const throw (DateOutOfRange);
       bool IsToday() const;
 
-      std::wstring GetUTCISO8601() const throw (DateOutOfRange);
+      std::wstring GetUTCISO8601Time() const throw (DateOutOfRange);
+      std::wstring GetUTCISO8601DateTime() const throw (DateOutOfRange);
 
-      std::wstring GetLocalISO8601() const throw (DateOutOfRange);
+      std::wstring GetLocalISO8601Time() const throw (DateOutOfRange);
       std::wstring GetLocalLocaleDate() const throw (DateOutOfRange);
       std::wstring GetLocalLocaleTime() const throw (DateOutOfRange);
       std::wstring GetLocalLocaleDateTime() const throw (DateOutOfRange);
