@@ -32,6 +32,9 @@ namespace Lum {
   {
   public:
     Boolean();
+
+    static Boolean* Create();
+    static Boolean* Create(Base::Model* model);
   };
 }
 
