@@ -47,6 +47,9 @@ namespace Lum {
               int x, int y, size_t w, size_t h);
 
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
+
+    static DateView* Create(bool horizontalFlex=false, bool verticalFlex=false);
+    static DateView* Create(Base::Model* model, bool horizontalFlex=false, bool verticalFlex=false);
   };
 }
 
