@@ -75,11 +75,11 @@ namespace Lum {
       };
 
     private:
-      Desc            description;
-      Menu*           preMenu;
-      Menu*           postMenu;
-      Model::SizeTRef value;
-      std::list<View> views;
+      Desc             description;
+      Menu*            preMenu;
+      Menu*            postMenu;
+      Model::NumberRef value;
+      std::list<View>  views;
 
     public:
       MultiView(const Desc& description);
@@ -87,10 +87,10 @@ namespace Lum {
       virtual ~MultiView();
 
       MultiView& SetMenu(Menu* pre, Menu* post);
-      MultiView& SetValue(Model::SizeT *value);
+      MultiView& SetValue(Model::Number* value);
       MultiView& AddView(const View& view);
 
-      Model::SizeT* GetValue() const;
+      Model::Number* GetValue() const;
 
       const Desc& GetDesc() const;
       Menu* GetPreMenu() const;
