@@ -31,22 +31,21 @@ namespace Lum {
   namespace Def {
     /**
      */
-    template<class N>
     class LUMAPI Number
     {
     private:
-      Desc                               description;
-      Base::Reference<Model::Number<N> > value;
+      Desc             description;
+      Model::NumberRef value;
 
     public:
-      Number(const Desc& description, Model::Number<N> *value)
+      Number(const Desc& description, Model::Number* value)
       : description(description),
         value(value)
       {
         assert(value!=NULL);
       }
 
-      Model::Number<N>* GetValue() const
+      Model::Number* GetValue() const
       {
         return value;
       }
@@ -56,29 +55,6 @@ namespace Lum {
         return description;
       }
     };
-
-#define Number_INSTANCIATION(name, type)\
-    class LUMAPI name : public Number<type>\
-    {\
-    public:\
-      name(const Desc& description, Model::Number<type> *value) : Number<type>(description, value) {};\
-    }
-
-    Number_INSTANCIATION(Int,int);
-
-    Number_INSTANCIATION(UInt,unsigned int);
-
-    Number_INSTANCIATION(Long,long);
-
-    Number_INSTANCIATION(ULong,unsigned long);
-
-    Number_INSTANCIATION(SizeT,size_t);
-
-    Number_INSTANCIATION(Float,float);
-
-    Number_INSTANCIATION(Double,double);
-
-#undef Number_INSTANCIATION
   }
 }
 
