@@ -46,21 +46,21 @@ namespace Lum {
     {
     private:
       Desc                description;
-      Model::SizeTRef     value;
+      Model::NumberRef    value;
       Model::TableRef     choices;
       Model::HeaderRef    choicesHeader;
       TableCellPainterRef tablePainter;
 
     public:
       OneOfMany(const Desc& description,
-                Model::SizeT* value,
+                Model::Number* value,
                 Model::Table* choices,
                 TableCellPainter* tablePainter=NULL);
 
       OneOfMany& SetChoicesHeader(Model::Header* choicesHeader);
 
       const Desc& GetDesc() const;
-      Model::SizeT* GetValue() const;
+      Model::Number* GetValue() const;
       Model::Table* GetChoices() const;
       Model::Header* GetChoicesHeader() const;
       TableCellPainter* GetTableCellPainter() const;
