@@ -71,7 +71,7 @@ namespace Lum {
       Model::DirRef                 dirList;
       Model::PathRef                path;
       Model::StringRef              full;
-      Model::SizeTRef               filter;
+      Model::ULongRef               filter;
       Model::BooleanRef             showHidden;
       Model::ActionRef              okAction;
       Model::ActionRef              reloadAction;
