@@ -22,13 +22,15 @@
 
 #include <Lum/Dlg/ActionDialog.h>
 
+#include <Lum/Edit/Text.h>
+
 namespace Lum {
   namespace Dlg {
 
     class LUMAPI Help : public Dlg::ActionDialog
     {
     private:
-      std::wstring helpText;
+      Edit::TextRef editContent;
 
     public:
       Help(const std::wstring& helpText);
