@@ -31,12 +31,12 @@ namespace Lum {
     class LUMAPI TimeSpanChooser : public ActionDialog
     {
     private:
-      Model::SizeTRef  seconds;
-      Model::ActionRef okAction;
-      bool             success;
+      Model::NumberRef  seconds;
+      Model::ActionRef  okAction;
+      bool              success;
 
     public:
-      TimeSpanChooser(Model::SizeT *seconds);
+      TimeSpanChooser(Model::Number* seconds);
       ~TimeSpanChooser();
 
       Lum::Object* GetContent();
