@@ -52,7 +52,8 @@ namespace Lum {
 
     void CalcSize();
     void Layout();
-    void Draw(int x, int y, size_t w, size_t h);
+    void Draw(OS::DrawInfo* draw,
+              int x, int y, size_t w, size_t h);
   };
 }
 
