@@ -62,6 +62,7 @@ namespace Lum {
 
   public:
     MenuStrip();
+    ~MenuStrip();
 
     bool VisitChildren(Visitor &visitor, bool onlyVisible);
 
@@ -74,7 +75,7 @@ namespace Lum {
     Menu* GetSelection() const;
     void AddPullDownMenu(Lum::Object* label, wchar_t sc, Menu* subMenu);
     void AddPullDownMenu(const std::wstring& label, Menu* subMenu);
-    Lum::Object* GetMouseSelected() const;
+    Lum::Object* GetMouseSelected(const OS::MouseEvent& event) const;
 
     void SelectPrevious();
     void SelectNext();
@@ -91,6 +92,7 @@ namespace Lum {
     Lum::Object*     label;          //! Label to display
     wchar_t          sc;             //! Shortcode for the menu
     Model::ActionRef shortcutAction; //! Action for shortcode keyboard event
+    bool             scAssigned;
 
   public:
     Menu*            subMenu; //! Menu that openes if selecting the pulldown menu
@@ -278,8 +280,8 @@ namespace Lum {
   class RadioItem : public MenuEntry
   {
   private:
-    Model::SizeTRef model;
-    size_t          value;
+    Model::NumberRef model;
+    size_t           value;
 
   public:
     RadioItem();
@@ -367,7 +369,7 @@ namespace Lum {
                      unsigned long qualifier=0,
                      const std::wstring& key=L"");
     void AddRadioItem(const std::wstring& label,
-                     Model::SizeT* model,
+                     Model::Number* model,
                      size_t index,
                      unsigned long qualifier=0,
                      const std::wstring& key=L"");
