@@ -30,10 +30,10 @@ namespace Lum {
     class LUMAPI Adjustment : public Base::Model
     {
     private:
-      SizeTRef top;
-      SizeTRef visible;
-      SizeTRef total;
-      size_t   stepSize;
+      ULongRef      top;
+      ULongRef      visible;
+      ULongRef      total;
+      unsigned long stepSize;
 
     public:
       Adjustment();
@@ -42,35 +42,35 @@ namespace Lum {
       void Off();
 
       bool IsValid() const;
-      size_t GetTop() const;
-      size_t GetBottom() const;
-      size_t GetVisible() const;
-      size_t GetTotal() const;
-      size_t IsCompletelyVisible() const;
+      unsigned long GetTop() const;
+      unsigned long GetBottom() const;
+      unsigned long GetVisible() const;
+      unsigned long GetTotal() const;
+      bool IsCompletelyVisible() const;
 
-      void Set(size_t top, size_t visible, size_t total);
+      void Set(unsigned long top, unsigned long visible, unsigned long total);
       void SetInvalid();
-      void SetTop(size_t top);
-      void SetDimension(size_t visible, size_t total);
+      void SetTop(unsigned long top);
+      void SetDimension(unsigned long visible, unsigned long total);
 
-      SizeT* GetTopModel() const;
-      SizeT* GetVisibleModel() const;
-      SizeT* GetTotalModel() const;
+      Number* GetTopModel() const;
+      Number* GetVisibleModel() const;
+      Number* GetTotalModel() const;
 
       void IncTop();
-      void IncTop(size_t stepSize);
+      void IncTop(unsigned long stepSize);
       void DecTop();
-      void DecTop(size_t stepSize);
+      void DecTop(unsigned long stepSize);
       void PageBack();
       void PageForward();
 
-      void MakeVisible(size_t pos);
-      void CenterOn(size_t pos);
+      void MakeVisible(unsigned long pos);
+      void CenterOn(unsigned long pos);
       void ShowFirstPage();
       void ShowLastPage();
 
-      void SetStepSize(size_t stepSize);
-      size_t GetStepSize() const;
+      void SetStepSize(unsigned long stepSize);
+      unsigned long GetStepSize() const;
     };
 
 #if defined(LUM_INSTANTIATE_TEMPLATES)
