@@ -31,9 +31,9 @@ namespace Lum {
   class LUMAPI Multi : public Control
   {
   private:
-    Model::SizeTRef      model;
+    Model::NumberRef     model;
     std::vector<Object*> list; /** A linked list of all children */
-    size_t               lastDrawn;
+    unsigned long        lastDrawn;
 
   public:
     Multi();
@@ -50,11 +50,11 @@ namespace Lum {
               int x, int y, size_t w, size_t h);
     void Hide();
 
-    Object* GetEntry(size_t pos) const;
-    size_t GetSize() const;
+    Object* GetEntry(unsigned long pos) const;
+    unsigned long GetSize() const;
 
     Multi* Append(Object* object);
-    Multi* Remove(size_t pos);
+    Multi* Remove(unsigned long pos);
     Multi* Remove(Object* object);
 
     void ShowPrevious();
