@@ -20,7 +20,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
-#include <Lum/Private/Config.h>
+#include <Lum/Features.h>
 
 // Cairo
 #if defined(__WIN32__) || defined(WIN32) || defined(__APPLE__)
@@ -29,11 +29,11 @@
   #include <cairo/cairo.h>
 #endif
 
-#if !defined(X_DISPLAY_MISSING) && !defined(__APPLE__)
+#if defined(LUM_HAVE_LIB_X)
   #include <cairo-xlib.h>
 #endif
 
-#if defined(__WIN32__) || defined(WIN32)
+#if defined(LUM_HAVE_LIB_WIN32)
   #include <cairo-win32.h>
 #endif
 
