@@ -35,8 +35,11 @@ namespace Lum {
         Font();
         virtual ~Font();
 
-        size_t StringWidth(const std::wstring& text, unsigned long style=normal);
-        void StringExtent(const std::wstring& text, OS::FontExtent& extent, unsigned long style=normal);
+        size_t StringWidth(const std::wstring& text,
+                           unsigned long style=normal);
+        void StringExtent(const std::wstring& text,
+                          OS::FontExtent& extent,
+                          unsigned long style=normal);
 
         OS::Font* Load();
       };
