@@ -45,7 +45,8 @@ namespace Lum {
     bool SetModel(Base::Model* model);
 
     void CalcSize();
-    void Draw(int x, int y, size_t w, size_t h);
+    void Draw(OS::DrawInfo* draw,
+              int x, int y, size_t w, size_t h);
 
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
   };
