@@ -34,9 +34,9 @@ namespace Lum {
   class LUMAPI RGBControl : public ControlComponent
   {
   private:
-    Model::IntRef   r;
-    Model::IntRef   g;
-    Model::IntRef   b;
+    Model::ULongRef r;
+    Model::ULongRef g;
+    Model::ULongRef b;
     Model::ColorRef model;
 
   public:
