@@ -41,8 +41,8 @@ namespace Lum {
   {
   protected:
     Model::BooleanRef boolModel;
-    Model::SizeTRef   sizeTModel;
-    size_t            index,orgState;
+    Model::NumberRef  numberModel;
+    unsigned long     index,orgState;
     bool              active;
 
   private:
