@@ -87,7 +87,7 @@ namespace Lum {
 
     size_t                refreshes;
     bool                  fullRefresh;
-    size_t                top;
+    unsigned long         top;
 
     TableCellPainterRef   painter;
     OS::FontRef           font;
