@@ -33,11 +33,11 @@ namespace Lum {
   class LUMAPI TimeSpan : public ControlComponent
   {
   private:
-    Model::ActionRef ups[5];
-    Model::ActionRef downs[5];
-    Model::SizeTRef  digits[5];
-    Text             *texts[5];
-    Model::SizeTRef  model;
+    Model::ActionRef  ups[5];
+    Model::ActionRef  downs[5];
+    Model::ULongRef   digits[5];
+    Text              *texts[5];
+    Model::NumberRef  model;
 
   public:
     TimeSpan();
@@ -48,7 +48,7 @@ namespace Lum {
 
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
 
-    static TimeSpan* Create(Model::SizeT* model=NULL,
+    static TimeSpan* Create(Model::Number* model=NULL,
                             bool horizontalFlex=false, bool verticalFlex=false);
   };
 }
