@@ -49,7 +49,7 @@ namespace Lum {
 
     Lum::Model::ActionRef backAction;
     Lum::Model::ActionRef cancelAction;
-    Lum::Model::SizeTRef  page;
+    Lum::Model::NumberRef page;
 
   public:
     Wizard();
