@@ -496,6 +496,11 @@ namespace Lum {
     }
 #endif
 
+    SystemTime::~SystemTime()
+    {
+      delete pimpl;
+    }
+
     SystemTime& SystemTime::operator=(const SystemTime& systemTime)
     {
       // Works also with self-assignment!
@@ -705,7 +710,7 @@ namespace Lum {
       return x.year==now.year && x.month==now.month && x.dayOfMonth==now.dayOfMonth;
     }
 
-    std::wstring SystemTime::GetUTCISO8601() const throw (DateOutOfRange)
+    std::wstring SystemTime::GetUTCISO8601Time() const throw (DateOutOfRange)
     {
       DateTime     time;
       std::wstring res;
@@ -726,7 +731,45 @@ namespace Lum {
       return res;
     }
 
-    std::wstring SystemTime::GetLocalISO8601() const throw (DateOutOfRange)
+    std::wstring SystemTime::GetUTCISO8601DateTime() const throw (DateOutOfRange)
+    {
+      DateTime     time;
+      std::wstring res;
+
+      res.reserve(10+1+8+1);
+
+      GetUTCDateTime(time);
+
+      // Date
+      res.append(1,(wchar_t)(L'0'+(time.year / 1000) % 10));
+      res.append(1,(wchar_t)(L'0'+(time.year /  100) % 10));
+      res.append(1,(wchar_t)(L'0'+(time.year /   10) % 10));
+      res.append(1,(wchar_t)(L'0'+(time.year /    1) % 10));
+      res.append(L"-");
+      res.append(1,(wchar_t)(L'0'+(time.month / 10) % 10));
+      res.append(1,(wchar_t)(L'0'+(time.month /  1) % 10));
+      res.append(L"-");
+      res.append(1,(wchar_t)(L'0'+(time.dayOfMonth / 10) % 10));
+      res.append(1,(wchar_t)(L'0'+(time.dayOfMonth /  1) % 10));
+
+      res.append(1,'T');
+
+      // Time
+      res.append(1,(wchar_t)(L'0'+(time.hour /   10) % 10));
+      res.append(1,(wchar_t)(L'0'+(time.hour /    1) % 10));
+      res.append(L":");
+      res.append(1,(wchar_t)(L'0'+(time.minute / 10) % 10));
+      res.append(1,(wchar_t)(L'0'+(time.minute /  1) % 10));
+      res.append(L":");
+      res.append(1,(wchar_t)(L'0'+(time.second / 10) % 10));
+      res.append(1,(wchar_t)(L'0'+(time.second /  1) % 10));
+
+      res.append(1,'Z');
+
+      return res;
+    }
+
+    std::wstring SystemTime::GetLocalISO8601Time() const throw (DateOutOfRange)
     {
       DateTime     time;
       std::wstring res;
