@@ -147,7 +147,9 @@ namespace Lum {
       The model is by default switched on.
     */
     Model::Model()
-    : depth(0),on(true),enabled(true)
+    : depth(0),
+      off(0),
+      enabled(true)
     {
       // no code
     }
@@ -328,7 +330,7 @@ namespace Lum {
       std::list<WatcherEntry>::iterator iter;
       std::set<MsgObject*>              signaled;
 
-      if (!on) {
+      if (off>0) {
         return;
       }
 
@@ -361,17 +363,23 @@ namespace Lum {
       Switch on communication between the Model and its
       listeners/viewers (derived from MsgObject.
 
-      If the model was switched of before Model::Notify will be
-      called with parameter 'NULL' signaling a major change to the
+      If the model was switched of before Model::Notify() will be
+      called with an instance of ResyncMsg signaling a major change to the
       listeners.
+      
+      Calls to On() and Off() are paired. So if you call Off() two times, you
+      must call On() two times, too, to get notification reactivated again.
+      
+      Calling On() on an already active model will trigger an assertion.
     */
     void Model::On(bool notify)
     {
-      if (!on) {
-        on=true;
-        if (notify) {
-          Notify();
-        }
+      assert(off>0);
+      
+      off--;
+      
+      if (IsOn() && notify) {
+        Notify();
       }
     }
 
@@ -381,15 +389,11 @@ namespace Lum {
 
       Use this method before starting some major change to a model and do
       not want the listeners to refresh for every single action. Call
-      Model::On to turn on communication and the initiate a major
-      refresh for all listeners.
+      Model::On() to turn on communication.
     */
     void Model::Off()
     {
-      if (on) {
-        on=false;
-        //Notify();
-      }
+      off++;
     }
 
     /**
@@ -397,7 +401,7 @@ namespace Lum {
     */
     bool Model::IsOn()
     {
-      return on;
+      return off==0;
     }
 
     bool Model::IsObserved() const
