@@ -541,34 +541,13 @@ namespace Lum {
       }
     }
 
-    std::wstring Path::GetApplicationConfigFile()
-    {
-      std::wstring file(::Lum::OS::display->GetAppName());
-
-      file.append(L".xml");
-#if defined(__WIN32__) || defined(WIN32)
-#else
-      ToLower(file);
-
-      file.insert(0,L".");
-#endif
-
-      return file;
-    }
-
     std::wstring Path::GetApplicationConfigPath()
     {
-      std::wstring dir;
-      std::wstring file(GetApplicationConfigFile());
-      Path         path;
+      std::wstring path;
 
-      if (!Manager::FileSystem::Instance()->GetEntry(Manager::FileSystem::userConfigDir,dir)) {
-        Manager::FileSystem::Instance()->GetEntry(Manager::FileSystem::userDir,dir);
-      }
+      Manager::FileSystem::Instance()->GetEntry(Manager::FileSystem::appConfigFile,path);
 
-      path.SetNativeDirAndFile(dir,file);
-
-      return path.GetPath();
+      return path;
     }
 
     Status Path::CreateDir(const std::wstring& nativePath)
