@@ -189,19 +189,19 @@ namespace Lum {
       buffer << std::setprecision(1);
 
       if (ceil(value)>=1024.0*1024*1024*1024*0.5) {
-        buffer << value/(1024.0*1024*1024*1024) << " TB";
+        buffer << value/(1024.0*1024*1024*1024) << " TiB";
       }
       else if (ceil(value)>=1024.0*1024*1024*0.5) {
-        buffer << value/(1024.0*1024*1024) << " GB";
+        buffer << value/(1024.0*1024*1024) << " GiB";
       }
       else if (ceil(value)>=1024.0*1024*0.5) {
-        buffer << value/(1024.0*1024) << " MB";
+        buffer << value/(1024.0*1024) << " MiB";
       }
       else if (ceil(value)>=1024.0*0.5) {
-        buffer << value/1024.0 << " KB";
+        buffer << value/1024.0 << " KiB";
       }
       else {
-        buffer << value << " Byte";
+        buffer << value << " B";
       }
 
       return buffer.str();
