@@ -299,32 +299,30 @@ namespace Lum {
   bool Blender::VisitChildren(Visitor &visitor, bool onlyVisible)
   {
     if (!onlyVisible) {
-      std::map<std::wstring,Object*>::iterator iter;
-
-      iter=topMap.begin();
-      while (iter!=topMap.end()) {
+      for (std::map<std::wstring,Object*>::iterator iter=topMap.begin();
+           iter!=topMap.end();
+           ++iter) {
         if (!visitor.Visit(iter->second)) {
           return false;
         }
-
-        ++iter;
       }
 
-      iter=bottomMap.begin();
-      while (iter!=bottomMap.end()) {
+      for (std::map<std::wstring,Object*>::iterator iter=bottomMap.begin();
+           iter!=bottomMap.end();
+           ++iter) {
         if (!visitor.Visit(iter->second)) {
           return false;
         }
-
-        ++iter;
       }
     }
     else {
-      if (top!=NULL && !visitor.Visit(top)) {
+      if (top!=NULL &&
+          !visitor.Visit(top)) {
         return false;
       }
 
-      if (bottom!=NULL && !visitor.Visit(bottom)) {
+      if (bottom!=NULL &&
+          !visitor.Visit(bottom)) {
         return false;
       }
     }
