@@ -309,7 +309,9 @@ namespace Lum {
       in the bounds of our button...
     */
 
-    if (event.type==OS::MouseEvent::down && PointIsIn(event) && event.button==OS::MouseEvent::button1) {
+    if (event.type==OS::MouseEvent::down &&
+        PointIsIn(event) &&
+        event.button==OS::MouseEvent::button1) {
       if (!model->IsStarted()) {
         /* We change our state to pressed and redisplay ourself */
         triggering=true;
@@ -500,6 +502,8 @@ namespace Lum {
     if (!scAssigned) {
       Dialog* window;
 
+      assert(GetWindow()!=NULL);
+
       window=dynamic_cast<Dialog*>(GetWindow()->GetMaster());
       if (window!=NULL) {
         if (shortCut!='\0') {
