@@ -150,16 +150,29 @@ namespace Lum {
     if (!visitor.Visit(prevYearButton)) {
       return false;
     }
+
     if (!visitor.Visit(prevMonthButton)) {
       return false;
     }
+
     if (!visitor.Visit(nextMonthButton)) {
       return false;
     }
+
     if (!visitor.Visit(nextYearButton)) {
       return false;
     }
 
+    if (!visitor.Visit(current)) {
+      return false;
+    }
+
+    for (size_t x=0; x<31+7; x++) {
+      if (!visitor.Visit(texts[x])) {
+        return false;
+      }
+    }
+
     return true;
   }
 
