@@ -22,7 +22,7 @@
 namespace Lum {
   namespace Def {
     OneOfMany::OneOfMany(const Desc& description,
-                         Model::SizeT* value,
+                         Model::Number* value,
                          Model::Table* choices,
                          TableCellPainter* tablePainter)
      : description(description),
@@ -51,7 +51,7 @@ namespace Lum {
       return description;
     }
 
-    Model::SizeT* OneOfMany::GetValue() const
+    Model::Number* OneOfMany::GetValue() const
     {
       return value;
     }
