@@ -29,6 +29,8 @@ namespace Lum {
 
     About::About()
     {
+      GetWindow()->SetScreenOrientationHint(OS::Window::screenOrientationBothSupported);
+
       SetExitAction(GetClosedAction());
     }
 
@@ -69,7 +71,7 @@ namespace Lum {
       About about;
 
       about.SetParent(parent);
-      about.SetTitle(L"About...");
+      about.SetTitle(L"About");
       about.SetAppInfo(info);
 
       if (about.Open()) {
