@@ -213,7 +213,7 @@ namespace Lum {
     : dirList(new Model::Dir()),
       path(new Model::Path()),
       full(new Model::String()),
-      filter(new Model::SizeT()),
+      filter(new Model::ULong()),
       showHidden(new Model::Boolean()),
       okAction(new Model::Action()),
       reloadAction(new Model::Action()),
@@ -684,7 +684,7 @@ namespace Lum {
       else if (model==filter &&
                dirList.Valid() &&
                options.Valid()) {
-        dirList->SetFilter(options->filters[filter->Get()-1]);
+        dirList->SetFilter(options->filters[filter->GetUnsignedLong()-1]);
         if (table!=NULL) {
           Load();
         }
