@@ -193,21 +193,18 @@ namespace Lum {
                      const std::wstring& caption,
                      const std::wstring& text)
     {
-      Msg *msg;
+      Msg msg;
 
-      msg=new Msg();
-      msg->SetParent(parent);
-      msg->SetTitle(L""/*caption*/);
-      msg->SetCaption(caption);
-      msg->SetText(text);
-      msg->AddButton(_ld(dlgButtonOk),Button::typeDefault,msg->GetClosedAction());
+      msg.SetParent(parent);
+      msg.SetTitle(L""/*caption*/);
+      msg.SetCaption(caption);
+      msg.SetText(text);
+      msg.AddButton(_ld(dlgButtonOk),Button::typeDefault,msg.GetClosedAction());
 
-      if (msg->Open()) {
-        msg->EventLoop();
-        msg->Close();
+      if (msg.Open()) {
+        msg.EventLoop();
+        msg.Close();
       }
-
-      delete msg;
     }
 
     size_t Msg::Ask(Dialog* parent,
@@ -223,26 +220,20 @@ namespace Lum {
                     const std::wstring& text,
                     const std::wstring& buttons)
     {
-      Msg    *msg;
-      size_t res;
+      Msg msg;
 
-      msg=new Msg();
-      msg->SetParent(parent);
-      msg->SetTitle(L""/*caption*/);
-      msg->SetCaption(caption);
-      msg->SetText(text);
-      msg->AddButtons(buttons);
+      msg.SetParent(parent);
+      msg.SetTitle(L""/*caption*/);
+      msg.SetCaption(caption);
+      msg.SetText(text);
+      msg.AddButtons(buttons);
 
-      if (msg->Open()) {
-        msg->EventLoop();
-        msg->Close();
+      if (msg.Open()) {
+        msg.EventLoop();
+        msg.Close();
       }
 
-      res=msg->GetResultIndex();
-
-      delete msg;
-
-      return res;
+      return msg.GetResultIndex();
     }
 
     size_t Msg::Ask(OS::Window* parent,
@@ -251,28 +242,22 @@ namespace Lum {
                     const std::wstring& buttons,
                     int x, int y)
     {
-      Msg    *msg;
-      size_t res;
+      Msg msg;
 
-      msg=new Msg();
-      msg->SetParent(parent);
-      msg->SetTitle(L""/*caption*/);
-      msg->SetPosition(::Lum::OS::Window::positionManual,::Lum::OS::Window::positionManual);
-      msg->GetWindow()->SetPos(x,y);
-      msg->SetCaption(caption);
-      msg->SetText(text);
-      msg->AddButtons(buttons);
+      msg.SetParent(parent);
+      msg.SetTitle(L""/*caption*/);
+      msg.SetPosition(::Lum::OS::Window::positionManual,::Lum::OS::Window::positionManual);
+      msg.GetWindow()->SetPos(x,y);
+      msg.SetCaption(caption);
+      msg.SetText(text);
+      msg.AddButtons(buttons);
 
-      if (msg->Open()) {
-        msg->EventLoop();
-        msg->Close();
+      if (msg.Open()) {
+        msg.EventLoop();
+        msg.Close();
       }
 
-      res=msg->GetResultIndex();
-
-      delete msg;
-
-      return res;
+      return msg.GetResultIndex();
     }
 
     size_t Msg::Ask(Dialog* parent,
