@@ -237,7 +237,7 @@ namespace Lum {
 
     void TableIndexValuePopup::PositionSelection()
     {
-      Model::SizeTRef model=dynamic_cast<Model::SizeT*>(GetModel());
+      Model::NumberRef model=dynamic_cast<Model::Number*>(GetModel());
 
       if (!model.Valid() ||
           model->IsNull() ||
@@ -246,13 +246,13 @@ namespace Lum {
         return;
       }
 
-      selectionModel->SelectLine(model->Get());
-      table->GetTableView()->MakeVisible(1,model->Get());
+      selectionModel->SelectLine(model->GetUnsignedLong());
+      table->GetTableView()->MakeVisible(1,model->GetUnsignedLong());
     }
 
     void TableIndexValuePopup::CopySelection()
     {
-      Model::SizeTRef model=dynamic_cast<Model::SizeT*>(GetModel());
+      Model::NumberRef model=dynamic_cast<Model::Number*>(GetModel());
 
       if (!model.Valid() ||
           model->IsNull() ||
