@@ -146,11 +146,10 @@ namespace Lum {
     Group::Layout();
   }
 
-  void FrameGroup::Draw(int x, int y, size_t w, size_t h)
+  void FrameGroup::Draw(OS::DrawInfo* draw,
+                        int x, int y, size_t w, size_t h)
   {
-    OS::DrawInfo *draw=GetDrawInfo();
-
-    Group::Draw(x,y,w,h); /* We must call Draw of our superclass */
+    Group::Draw(draw,x,y,w,h); /* We must call Draw of our superclass */
 
     if (!OIntersect(x,y,w,h)) {
       return;
