@@ -82,9 +82,10 @@ namespace Lum {
     Object::CalcSize();
   }
 
-  void Image::Draw(int x, int y, size_t w, size_t h)
+  void Image::Draw(OS::DrawInfo* draw,
+                   int x, int y, size_t w, size_t h)
   {
-    Object::Draw(x,y,w,h);
+    Object::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -97,15 +98,12 @@ namespace Lum {
     }
 
     if (osImage.Valid()) {
-      OS::DrawInfo *draw=GetDrawInfo();
-
       osImage->DrawStretched(draw,
                              this->x,this->y,
                              HorizontalFlex() ? this->width : osImage->GetWidth(),
                              VerticalFlex() ? this->height : osImage->GetHeight());
     }
     else if (extImage.Valid()) {
-      OS::DrawInfo *draw=GetDrawInfo();
       extImage->DrawSub(draw,
                         0,0,
                         extImage->GetWidth(),extImage->GetHeight(),
@@ -114,7 +112,6 @@ namespace Lum {
     }
     else if (extStatefulImage.Valid() &&
              extStatefulImage->IsValid()) {
-      OS::DrawInfo *draw=GetDrawInfo();
       Images::ImageRef image=extStatefulImage->GetNormalImage();
 
       if (!draw->disabled && draw->selected && extStatefulImage->GetNormalSelectedImage()!=NULL) {
