@@ -57,6 +57,13 @@ namespace Lum {
     }
 
     Manager::Manager()
+    : lightThemePostfix(L"_light"),
+      darkThemePostfix(L"_dark"),
+      normalImagePostfix(L"_normal"),
+      normalSelectedImagePostfix(L"_selected"),
+      disabledImagePostfix(L"_disabled"),
+      disabledSelectedImagePostfix(L"_disabled_selected"),
+      activatedImagePostfix(L"_activated")
     {
 #ifdef HAVE_LIB_PNG
       loader.push_back(new LoaderPNG);
@@ -95,6 +102,20 @@ namespace Lum {
       return *this;
     }
 
+    Manager& Manager::SetLightThemePostfix(const std::wstring& postfix)
+    {
+      lightThemePostfix=postfix;
+
+      return *this;
+    }
+
+    Manager& Manager::SetDarkThemePostfix(const std::wstring& postfix)
+    {
+      darkThemePostfix=postfix;
+
+      return *this;
+    }
+
     Manager& Manager::SetNormalImagePostfix(const std::wstring& postfix)
     {
       normalImagePostfix=postfix;
@@ -156,10 +177,32 @@ namespace Lum {
       search pathes for building an complete filesystem path.
      */
     bool Manager::LoadApplication(const std::wstring& basename,
-                                  ImageRef &image) const
+                                  ImageRef &image,
+                                  bool showError) const
     {
       assert(image.Valid());
 
+      std::wstring            base,suffix,scheme;
+      std::wstring::size_type pos;
+
+      pos=basename.find_last_of('.');
+
+      if (pos==std::wstring::npos) {
+        base=basename;
+        suffix=L"";
+      }
+      else {
+        base=basename.substr(0,pos);
+        suffix=basename.substr(pos);
+      }
+
+      if (OS::display->GetTheme()->IsLightTheme()) {
+        scheme=lightThemePostfix;
+      }
+      else {
+        scheme=darkThemePostfix;
+      }
+
       for (std::list<Loader*>::const_iterator iter=loader.begin();
            iter!=loader.end();
            ++iter) {
@@ -170,53 +213,98 @@ namespace Lum {
           Base::Path   p(*path);
           std::wstring filename;
 
-          p.SetBaseName(basename);
+          if (!scheme.empty()) {
+            p.SetBaseName(base+scheme+suffix);
+            filename=p.GetPath();
+
+            if ((*iter)->CanLoad(filename) &&
+                (*iter)->Load(filename,image)) {
+              return true;
+            }
+          }
+
+          p.SetBaseName(base+suffix);
           filename=p.GetPath();
 
-          if ((*iter)->CanLoad(filename)) {
-            return (*iter)->Load(filename,image);
+          if ((*iter)->CanLoad(filename) &&
+              (*iter)->Load(filename,image)) {
+            return true;
+          }
+
+          p.AppendDir(Lum::Base::NumberToWString(OS::display->GetTheme()->GetIconWidth())+
+                      L"x"+
+                      Lum::Base::NumberToWString(OS::display->GetTheme()->GetIconHeight()));
+                      
+
+          if (!scheme.empty()) {
+            p.SetBaseName(base+scheme+suffix);
+            filename=p.GetPath();
+
+            if ((*iter)->CanLoad(filename) &&
+                (*iter)->Load(filename,image)) {
+              return true;
+            }
+          }
+                      
+          p.SetBaseName(base+suffix);
+          filename=p.GetPath();
+
+          if ((*iter)->CanLoad(filename) &&
+              (*iter)->Load(filename,image)) {
+            return true;
           }
         }
       }
 
-      for (std::list<Base::Path>::const_iterator path=applicationSearchPaths.begin();
-           path!=applicationSearchPaths.end();
-           ++path) {
-        Base::Path   p(*path);
-        std::wstring filename=p.GetPath();
+      if (showError) {
+        for (std::list<Base::Path>::const_iterator path=applicationSearchPaths.begin();
+             path!=applicationSearchPaths.end();
+             ++path) {
+          Base::Path   p(*path);
 
-        p.SetBaseName(basename);
-        std::cerr << "Cannot load '" << Lum::Base::WStringToString(basename) << "' as '" << Lum::Base::WStringToString(filename) << "'!" << std::endl;
-        filename=p.GetPath();
+          if (!scheme.empty()) {
+            p.SetBaseName(base+scheme+suffix);
+            std::cerr << "Cannot load '" << Lum::Base::WStringToString(basename) << "' as '" << Lum::Base::WStringToString(p.GetPath()) << "'!" << std::endl;
+          }
+
+          p.SetBaseName(base+scheme+suffix);
+          std::cerr << "Cannot load '" << Lum::Base::WStringToString(basename) << "' as '" << Lum::Base::WStringToString(p.GetPath()) << "'!" << std::endl;
+        }
       }
 
       return false;
     }
 
+    /**
+     * Loads an individual image from the filessytem using all configured application image
+      search pathes for building an complete filesystem path.
+     */
+    bool Manager::LoadApplication(const std::wstring& basename,
+                                  ImageRef &image) const
+    {
+      return LoadApplication(basename,image,true);
+    }
+
     /**
      * Loading an application image by using the configured application pathes as
      * possible filesystem pathes and using the configured application state images postfixes
-     * as image postfix.
+     * as image postfix. Also support for light themed or dark themed variant of
+     * images are also supported.
      *
      * Returns: True if the 'normal' images can be loaded, else false.
      *
      * Example: Loading an image 'help.png' with application path '/usr/local/share/app/'
-     * and postfix "disabled" as postfix for an 'disabled' image will result in a filesystem path
-     * of '/usr/local/share/app/help_disabled.png'.
+     * and postfix "disabled" as postfix for an 'disabled' image and "_light"
+     * as the postfix for a light theme will result in a
+     * filesystem path
+     * of '/usr/local/share/app/help_disabled_light.png'.
      */
     bool Manager::LoadApplication(const std::wstring& basename,
                                   StatefulImageRef &image) const
     {
-      std::wstring            base,suffix,scheme;
+      std::wstring            base,suffix;
       std::wstring::size_type pos;
 
-      if (OS::display->GetTheme()->IsLightTheme()) {
-        scheme=L"_light";
-      }
-      else {
-        scheme=L"_dark";
-      }
-
       pos=basename.find_last_of('.');
 
       if (pos==std::wstring::npos) {
@@ -225,13 +313,12 @@ namespace Lum {
       }
       else {
         base=basename.substr(0,pos);
-        suffix=basename.substr(pos+1);
+        suffix=basename.substr(pos);
       }
 
       ImageRef i=Lum::Images::Factory::factory->CreateImage();
 
-      if (!LoadApplication(base+normalImagePostfix+scheme+L"."+suffix,i) &&
-          !LoadApplication(base+normalImagePostfix+L"."+suffix,i)) {
+      if (!LoadApplication(base+normalImagePostfix+suffix,i,true)) {
         return false;
       }
 
@@ -240,15 +327,13 @@ namespace Lum {
       i=Lum::Images::Factory::factory->CreateImage();
 
       if (!normalSelectedImagePostfix.empty() &&
-          (LoadApplication(base+normalSelectedImagePostfix+scheme+L"."+suffix,i) ||
-           LoadApplication(base+normalSelectedImagePostfix+L"."+suffix,i))) {
+          LoadApplication(base+normalSelectedImagePostfix+suffix,i,false)) {
         image->SetNormalSelectedImage(i);
         i=Lum::Images::Factory::factory->CreateImage();
       }
 
       if (!disabledImagePostfix.empty() &&
-          (LoadApplication(base+disabledImagePostfix+scheme+L"."+suffix,i) ||
-           LoadApplication(base+disabledImagePostfix+L"."+suffix,i))) {
+          LoadApplication(base+disabledImagePostfix+suffix,i,false)) {
         image->SetDisabledImage(i);
         i=Lum::Images::Factory::factory->CreateImage();
       }
@@ -259,8 +344,7 @@ namespace Lum {
       }
 
       if (!disabledSelectedImagePostfix.empty() &&
-          (LoadApplication(base+disabledSelectedImagePostfix+scheme+L"."+suffix,i) ||
-           LoadApplication(base+disabledSelectedImagePostfix+L"."+suffix,i))) {
+          LoadApplication(base+disabledSelectedImagePostfix+suffix,i,false)) {
         image->SetDisabledSelectedImage(i);
         i=Lum::Images::Factory::factory->CreateImage();
       }
@@ -271,8 +355,7 @@ namespace Lum {
       }
 
       if (!activatedImagePostfix.empty() &&
-          (LoadApplication(base+activatedImagePostfix+scheme+L"."+suffix,i) ||
-           LoadApplication(base+activatedImagePostfix+L"."+suffix,i))) {
+          LoadApplication(base+activatedImagePostfix+suffix,i,false)) {
         image->SetActivatedImage(i);
       }
 
