@@ -24,27 +24,28 @@
 namespace Lum {
   namespace Model {
 
-    void Calendar::SetToCurrent()
+    bool Calendar::SetToCurrent()
     {
-      value.value.SetToCurrent();
-      value.isNull=false;
+      Base::Calendar now;
 
-      Notify();
+      return SetDate(now.GetDayOfMonth(),now.GetMonth(),now.GetYear());
     }
 
-    void Calendar::SetDate(int dayOfMonth, int month, int year)
+    bool Calendar::SetDate(int dayOfMonth, int month, int year)
     {
       if (!value.isNull &&
           value.value.GetDayOfMonth()==dayOfMonth &&
           value.value.GetMonth()==month &&
           value.value.GetYear()==year) {
-        return;
+        return false;
       }
 
       value.value.SetDate(dayOfMonth,month,year);
       value.isNull=false;
 
       Notify();
+
+      return true;
     }
   }
 }
