@@ -19,7 +19,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
-#include <assert.h>
+#include <cassert>
 
 namespace Lum {
   namespace Model {
@@ -56,6 +56,11 @@ namespace Lum {
       Notify(msg);
     }
 
+    bool Selection::HasSelectionChanged(Base::Model* model, const Base::ResyncMsg& msg) const
+    {
+      return model==this &&
+             dynamic_cast<const Selected*>(&msg)!=NULL;
+    }
 
     NoneSelection::NoneSelection()
     : Selection(lineBased)
@@ -154,10 +159,8 @@ namespace Lum {
     void SingleLineSelection::OnClear()
     {
       line=0;
-
-      Notify();
-
     }
+
     void SingleLineSelection::SelectLine(size_t line)
     {
       assert(line>0);
