@@ -24,27 +24,28 @@
 namespace Lum {
   namespace Model {
 
-    void Time::SetToNow()
+    bool Time::SetToNow()
     {
-      value.value.SetToNow();
-      value.isNull=false;
+      Base::Time now;
 
-      Notify();
+      return SetTime(now.GetHour(),now.GetMinute(),now.GetSecond());
     }
 
-    void Time::SetTime(unsigned char hour, unsigned char minute, unsigned char second)
+    bool Time::SetTime(unsigned char hour, unsigned char minute, unsigned char second)
     {
       if (!value.isNull &&
           value.value.GetHour()==hour &&
           value.value.GetMinute()==minute &&
           value.value.GetSecond()==second) {
-        return;
+        return false;
       }
 
       value.value.Set(hour,minute,second);
       value.isNull=false;
 
       Notify();
+
+      return true;
     }
 
     void Time::IncHour()
