@@ -24,7 +24,7 @@
 namespace Lum {
 
   Multi::Multi()
-   : lastDrawn(std::numeric_limits<size_t>::max())
+   : lastDrawn(std::numeric_limits<unsigned long>::max())
   {
     // no code
   }
@@ -39,7 +39,9 @@ namespace Lum {
   bool Multi::VisitChildren(Visitor &visitor, bool onlyVisible)
   {
     if (onlyVisible) {
-      if (model.Valid() && !model->IsNull() && !visitor.Visit(list[model->Get()])) {
+      if (model.Valid() &&
+          !model->IsNull() &&
+          !visitor.Visit(list[model->GetUnsignedLong()])) {
         return false;
       }
     }
@@ -56,7 +58,7 @@ namespace Lum {
 
   bool Multi::SetModel(Base::Model* model)
   {
-    this->model=dynamic_cast<Model::SizeT*>(model);
+    this->model=dynamic_cast<Model::Number*>(model);
 
     Control::SetModel(this->model);
 
@@ -98,7 +100,7 @@ namespace Lum {
   {
     if (lastDrawn<list.size() &&
         ((!model.Valid() || model->IsNull()) ||
-         (model.Valid() && !model->IsNull() && lastDrawn!=model->Get()))) {
+         (model.Valid() && !model->IsNull() && lastDrawn!=model->GetUnsignedLong()))) {
       /*
         This is a little trick:
         We must hide the old object, but we do not want it to clean up the
@@ -125,7 +127,7 @@ namespace Lum {
       return;
     }
 
-    lastDrawn=model->Get();
+    lastDrawn=model->GetUnsignedLong();
   }
 
   void Multi::Hide()
@@ -139,12 +141,12 @@ namespace Lum {
     }
   }
 
-  size_t Multi::GetSize() const
+  unsigned long Multi::GetSize() const
   {
     return list.size();
   }
 
-  Object* Multi::GetEntry(size_t pos) const
+  Object* Multi::GetEntry(unsigned long pos) const
   {
     return list[pos];
   }
@@ -174,7 +176,7 @@ namespace Lum {
     return this;
   }
 
-  Multi* Multi::Remove(size_t /*pos*/)
+  Multi* Multi::Remove(unsigned long /*pos*/)
   {
     assert(false);
 
@@ -183,8 +185,8 @@ namespace Lum {
 
   void Multi::ShowPrevious()
   {
-    if (model->Get()>0) {
-      model->Set(model->Get()-1);
+    if (model->GetUnsignedLong()>0) {
+      model->Set(model->GetUnsignedLong()-1);
     }
     else {
       model->Set(list.size()-1);
@@ -193,8 +195,8 @@ namespace Lum {
 
   void Multi::ShowNext()
   {
-    if (model->Get()<list.size()-1) {
-      model->Set(model->Get()+1);
+    if (model->GetUnsignedLong()<list.size()-1) {
+      model->Set(model->GetUnsignedLong()+1);
     }
     else {
       model->Set(0);
