@@ -63,9 +63,9 @@ namespace Lum {
       void DefaultBehaviour::ApplyMultiViewDlg(Dialog* dialog,
                                                const Def::MultiView& multiView) const
       {
-        Tab                  *tab=Tab::Create(true,true);
-        Lum::Model::SizeTRef value=multiView.GetValue();
-        Def::Menu            *menu=NULL;
+        Tab                   *tab=Tab::Create(true,true);
+        Lum::Model::NumberRef value=multiView.GetValue();
+        Def::Menu             *menu=NULL;
 
         if (multiView.GetPreMenu()!=NULL) {
           menu=new Def::Menu(*multiView.GetPreMenu());
