@@ -21,6 +21,10 @@
 
 #include <Lum/OS/Cairo/Driver.h>
 
+#if defined(__WIN32__) || defined(WIN32)
+  #include <cairo-win32.h>
+#endif 
+
 namespace Lum {
   namespace OS {
     namespace Cairo {
