@@ -272,8 +272,11 @@ namespace Lum {
         raw();
         //Images::Factory::Set(OS::Factory::factory->CreateImageFactory(this));
 
-        scrWidth=COLS;
-        scrHeight=LINES;
+        screenWidth=COLS;
+        screenHeight=LINES;
+
+        workAreaWidth=screenWidth;
+        workAreaHeight=screenHeight;
 
         type=typeTextual;
 
@@ -303,9 +306,6 @@ namespace Lum {
           color[i]=theme->GetColor((ColorIndex)i);
         }
 
-        workAreaWidth=scrWidth;
-        workAreaHeight=scrHeight;
-
         multiClickTime=200;
 
         eventLoop=new UnixEventLoop();
