@@ -17,7 +17,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
-#include <Lum/OS/Hildon/KeyboardManager.h>
+#include <Lum/OS/Hildon/Keyboard.h>
 
 #include <X11/Xatom.h>
 
@@ -38,7 +38,7 @@ namespace Lum {
   namespace OS {
     namespace Hildon {
 
-      KeyboardManager::KeyboardManager()
+      Keyboard::Keyboard()
       : window(NULL),
         object(NULL)
       {
@@ -50,34 +50,32 @@ namespace Lum {
         // no code
       }
 
-      KeyboardManager::~KeyboardManager()
+      Keyboard::~Keyboard()
       {
         // no code
       }
 
-      void KeyboardManager::Shutdown()
+      void Keyboard::Shutdown()
       {
-        HideKeyboard();
+        //HideKeyboard();
       }
 
-      void KeyboardManager::OnWindowFocusIn(OS::Window* window)
+      void Keyboard::OnWindowFocusIn(OS::Window* window)
       {
         this->window=window;
         this->object=NULL;
       }
 
-      void KeyboardManager::OnWindowFocusOut(OS::Window* window)
+      void Keyboard::OnWindowFocusOut(OS::Window* window)
       {
         // no code
       }
 
-      void KeyboardManager::OnFocusChange(OS::Window* window,
-                                          Lum::Object* oldObject,
-                                          Lum::Object* newObject)
+      void Keyboard::OnFocusChange(OS::Window* window,
+                                   Lum::Object* oldObject,
+                                   Lum::Object* newObject)
       {
-        //std::cout << "Focus change: " << window << " " << oldObject << " " << newObject << std::endl;
         if (this->window!=window) {
-          //std::cerr << "Wrong window!" << std::endl;
           return;
         }
 
@@ -101,6 +99,7 @@ namespace Lum {
         }
         else if (newObject!=NULL && newObject->RequestsKeyboard()) { // "show" case
           object=newObject;
+          SendInputMode();
           ShowKeyboard();
         }
         else { // "hide" case
@@ -110,9 +109,9 @@ namespace Lum {
 #endif
       }
 
-      void KeyboardManager::OnMouseClick(Window* window,
-                                         Lum::Object* object,
-                                         MouseEvent* event)
+      void Keyboard::OnMouseClick(Window* window,
+                                  Lum::Object* object,
+                                  MouseEvent* event)
       {
         if (this->window!=window) {
           //std::cerr << "Wrong window!" << std::endl;
@@ -125,12 +124,13 @@ namespace Lum {
             object->RequestsKeyboard() &&
             object->GetIMHandler()!=NULL &&
             object->GetIMHandler()->IsInEditingArea(event)) {
+          SendInputMode();
           ShowKeyboard();
         }
 #endif
       }
 
-      bool KeyboardManager::HandleEvent(OS::Window* window, OS::Event* event)
+      bool Keyboard::HandleEvent(OS::Window* window, OS::Event* event)
       {
         XEvent x11Event;
 
@@ -178,34 +178,16 @@ namespace Lum {
           }
           else if (msg->type==HILDON_IM_CONTEXT_CONFIRM_SENTENCE_START) {
             //std::cout << "HILDON_IM_CONTEXT_CONFIRM_SENTENCE_START" << std::endl;
-
-            ::XEvent event;
-
-            memset(&event,0,sizeof(event));
-            event.xclient.type=ClientMessage;
-            event.xclient.window=imWindow;
-            event.xclient.message_type=XInternAtom(display->display,
-                                                   HILDON_IM_ACTIVATE_NAME,false);
-            event.xclient.format=HILDON_IM_ACTIVATE_FORMAT;
-
-            HildonIMActivateMessage *msg = reinterpret_cast<HildonIMActivateMessage *>(&event.xclient.data);
-
-            msg->input_window=dynamic_cast<X11::Window*>(window)->GetDrawable();
-            msg->app_window=dynamic_cast<X11::Window*>(window)->GetDrawable();
-            msg->cmd=HILDON_IM_UP;
-            msg->trigger=triggerType;
-
-            if (XSendEvent(display->display,imWindow,False,NoEventMask,&event)==0) {
-              std::cerr << "Error while sending _HILDON_IM_ACTIVATE" << std::endl;
-            }
-            XSync(display->display,False);
+            if (!SendCommand(HILDON_IM_LOW)) {
+              std::cerr << "Error while sending LOW (_HILDON_IM_ACTIVATE)" << std::endl;
+        }
           }
           else if (msg->type==HILDON_IM_CONTEXT_FLUSH_PREEDIT) {
             //std::cout << "HILDON_IM_CONTEXT_FLUSH_PREEDIT" << std::endl;
           }
-          /*else if (msg->type==HILDON_IM_CONTEXT_CANCEL_PREEDIT) {
+          else if (msg->type==HILDON_IM_CONTEXT_CANCEL_PREEDIT) {
             //std::cout << "HILDON_IM_CONTEXT_CANCEL_PREEDIT" << std::endl;
-          }*/
+          }
           else if (msg->type==HILDON_IM_CONTEXT_BUFFERED_MODE) {
             //std::cout << "HILDON_IM_CONTEXT_BUFFERED_MODE" << std::endl;
           }
@@ -218,9 +200,9 @@ namespace Lum {
           else if (msg->type==HILDON_IM_CONTEXT_SURROUNDING_MODE) {
             //std::cout << "HILDON_IM_CONTEXT_SURROUNDING_MODE" << std::endl;
           }
-          /*else if (msg->type==HILDON_IM_CONTEXT_PREEDIT_MODE) {
+          else if (msg->type==HILDON_IM_CONTEXT_PREEDIT_MODE) {
             //std::cout << "HILDON_IM_CONTEXT_PREEEDIT_MODE" << std::endl;
-          }*/
+          }
           else if (msg->type==HILDON_IM_CONTEXT_CLIPBOARD_COPY) {
             //std::cout << "HILDON_IM_CONTEXT_CLIPBOARD_COPY" << std::endl;
             Copy();
@@ -243,7 +225,6 @@ namespace Lum {
 #if HILDON_CHECK_VERSION(2,1,0)
           else if (msg->type==HILDON_IM_CONTEXT_REQUEST_SURROUNDING_FULL) {
             //std::cout << "HILDON_IM_CONTEXT_REQUEST_SURROUNDING_FULL" << std::endl;
-
             SendSurrounding();
           }
 #endif
@@ -259,12 +240,30 @@ namespace Lum {
           else if (msg->type==HILDON_IM_CONTEXT_ENTER_ON_FOCUS) {
             //std::cout << "HILDON_IM_CONTEXT_ENTER_ON_FOCUS" << std::endl;
           }
-          /*else if (msg->type==HILDON_IM_CONTEXT_SPACE_AFTER_COMMIT) {
+          else if (msg->type==HILDON_IM_CONTEXT_SPACE_AFTER_COMMIT) {
             //std::cout << "HILDON_IM_CONTEXT_SPACE_AFTER_COMMIT" << std::endl;
           }
           else if (msg->type==HILDON_IM_CONTEXT_NO_SPACE_AFTER_COMMIT) {
             //std::cout << "HILDON_IM_CONTEXT_NO_SPACE_AFTER_COMMIT" << std::endl;
-          }*/
+          }
+          else if (msg->type==HILDON_IM_CONTEXT_SHIFT_LOCKED) {
+            //std::cout << "HILDON_IM_CONTEXT_SHIFT_LOCKED" << std::endl;
+          }
+          else if (msg->type==HILDON_IM_CONTEXT_SHIFT_UNLOCKED) {
+            //std::cout << "HILDON_IM_CONTEXT_SHIFT_UNLOCKED" << std::endl;
+          }
+          else if (msg->type==HILDON_IM_CONTEXT_LEVEL_LOCKED) {
+            //std::cout << "HILDON_IM_CONTEXT_LEVEL_LOCKED" << std::endl;
+          }
+          else if (msg->type==HILDON_IM_CONTEXT_LEVEL_UNLOCKED) {
+            //std::cout << "HILDON_IM_CONTEXT_LEVEL_UNLOCKED" << std::endl;
+          }
+          else if (msg->type==HILDON_IM_CONTEXT_SHIFT_UNSTICKY) {
+            //std::cout << "HILDON_IM_CONTEXT_SHIFT_UNSTICKY" << std::endl;
+          }
+          else if (msg->type==HILDON_IM_CONTEXT_LEVEL_UNSTICKY) {
+            //std::cout << "HILDON_IM_CONTEXT_LEVEL_UNSTICKY" << std::endl;
+          }
           else {
             //std::cout << "got HILDON-COM " << std::hex << msg->type << std::endl;
           }
@@ -299,9 +298,9 @@ namespace Lum {
         else if (x11Event.xclient.message_type==XInternAtom(display->display,
                                                             HILDON_IM_SURROUNDING_CONTENT_NAME,
                                                             false)) {
-          HildonIMSurroundingContentMessage *msg = reinterpret_cast<HildonIMSurroundingContentMessage *>(&x11Event.xclient.data);
+          HildonIMSurroundingContentMessage *msg=reinterpret_cast<HildonIMSurroundingContentMessage *>(&x11Event.xclient.data);
 
-          //std::cout << "HILDON_IM_SURROUNDING_CONTENT '" << msg->surrounding << "'" << std::endl;
+          //std::cout << "HILDON_IM_SURROUNDING_CONTENT " << msg->msg_flag << " '" << msg->surrounding << "'" << std::endl;
 
           if (msg->msg_flag==HILDON_IM_MSG_START) {
             buffer.clear();
@@ -353,8 +352,78 @@ namespace Lum {
         return false;
       }
 
-      void KeyboardManager::SendSurrounding()
+      void Keyboard::SendInputMode()
       {
+        //std::cout << "Keyboard::SendInputMode()" << std::endl;
+        ::XEvent     event;
+        ::Window     imWindow=GetKeyboardWindow();
+        X11::Display *display=dynamic_cast<X11::Display*>(Lum::OS::display);
+        std::wstring inputTypeHint;
+
+        if (display==NULL) {
+          return;
+        }
+
+        if (imWindow==None) {
+          return;
+        }
+
+        assert(object!=NULL);
+        assert(object->GetIMHandler()!=NULL);
+
+        inputTypeHint=object->GetInputTypeHint(),
+
+        memset(&event,0,sizeof(event));
+        event.xclient.type=ClientMessage;
+        event.xclient.window=imWindow;
+        event.xclient.message_type=XInternAtom(display->display,
+                                               HILDON_IM_INPUT_MODE_NAME,
+                                               false);
+        event.xclient.format=HILDON_IM_INPUT_MODE_FORMAT;
+
+        HildonIMInputModeMessage *msg=reinterpret_cast<HildonIMInputModeMessage *>(&event.xclient.data);
+
+        msg->input_mode=HILDON_GTK_INPUT_MODE_FULL;
+
+        if (inputTypeHint==Lum::Object::inputTypeAlpha) {
+          msg->input_mode=HILDON_GTK_INPUT_MODE_ALPHA;
+        }
+        else if (inputTypeHint==Lum::Object::inputTypeUnsignedBinaryNumber) {
+          msg->input_mode=HILDON_GTK_INPUT_MODE_NUMERIC;
+        }
+        else if (inputTypeHint==Lum::Object::inputTypeUnsignedOctalNumber) {
+          msg->input_mode=HILDON_GTK_INPUT_MODE_NUMERIC;
+        }
+        else if (inputTypeHint==Lum::Object::inputTypeSignedDecimalNumber) {
+          msg->input_mode=HILDON_GTK_INPUT_MODE_NUMERIC;
+        }
+        else if (inputTypeHint==Lum::Object::inputTypeUnsignedDecimalNumber) {
+          msg->input_mode=HILDON_GTK_INPUT_MODE_NUMERIC;
+        }
+        else if (inputTypeHint==Lum::Object::inputTypeUnsignedHexadecimalNumber) {
+          msg->input_mode=HILDON_GTK_INPUT_MODE_HEXA;
+        }
+        else if (inputTypeHint==Lum::Object::inputTypeSignedFloatNumber) {
+          msg->input_mode=HILDON_GTK_INPUT_MODE_FULL;
+        }
+        else if (inputTypeHint==Lum::Object::inputTypeUnsignedFloatNumber) {
+          msg->input_mode=HILDON_GTK_INPUT_MODE_FULL;
+        }
+        else if (inputTypeHint==Lum::Object::inputTypePhoneNumber) {
+          msg->input_mode=HILDON_GTK_INPUT_MODE_TELE;
+        }
+
+        msg->default_input_mode=HILDON_GTK_INPUT_MODE_FULL;
+
+        if (XSendEvent(display->display,imWindow,False,NoEventMask,&event)==0) {
+          std::cerr << "Error while sending OpenKeyboard (_HILDON_IM_INPUT_MODE)" << std::endl;
+        }
+      }
+
+      void Keyboard::SendSurrounding()
+      {
+        //std::cout << "Keyboard::SendSurrounding()" << std::endl;
+
         ::XEvent     event;
         std::wstring data;
         std::string  utf8Data;
@@ -418,13 +487,12 @@ namespace Lum {
           }
         }
 
-        /*
         msg->msg_flag=HILDON_IM_MSG_END;
         msg->surrounding[0]='\0';
 
         if (XSendEvent(display->display,imWindow,False,NoEventMask,&event)==0) {
           std::cerr << "Error while sending HILDON_IM_SURROUNDING_CONTENT_NAME" << std::endl;
-        }*/
+        }
 
         memset(&event,0,sizeof(event));
         event.xclient.type=ClientMessage;
@@ -437,7 +505,7 @@ namespace Lum {
         HildonIMSurroundingMessage *smsg = reinterpret_cast<HildonIMSurroundingMessage *>(&event.xclient.data);
 
         smsg->commit_mode=HILDON_IM_COMMIT_SURROUNDING;
-        smsg->offset_is_relative=0;
+        smsg->offset_is_relative=false;
         smsg->cursor_offset=cursorPos;
 
         if (XSendEvent(display->display,imWindow,False,NoEventMask,&event)==0) {
@@ -445,7 +513,7 @@ namespace Lum {
         }
       }
 
-      void KeyboardManager::SendClipboardSelectionQueryResponse()
+      void Keyboard::SendClipboardSelectionQueryResponse()
       {
         ::XEvent     event;
         bool         hasSelection;
@@ -479,8 +547,9 @@ namespace Lum {
         }
       }
 
-      void KeyboardManager::SendKey(Key key)
+      void Keyboard::SendKey(Key key)
       {
+        //std::cout << "Keyboard::SendKey(" << key << ")" << std::endl;
         X11::KeyEvent keyEvent;
 
         keyEvent.key=key;
@@ -494,7 +563,7 @@ namespace Lum {
         window->HandleEvent(&keyEvent);
       }
 
-      void KeyboardManager::ShowKeyboard()
+      bool Keyboard::SendCommand(HildonIMCommand command)
       {
         assert(window!=0);
 
@@ -502,14 +571,14 @@ namespace Lum {
 
         if (display==NULL) {
           std::cerr << "No display!" << std::endl;
-          return;
+          return false;
         }
 
         ::Window imWindow=GetKeyboardWindow();
 
         if (imWindow==None) {
           std::cerr << "No IM window!" << std::endl;
-          return;
+          return false;
         }
 
         ::XEvent event;
@@ -526,55 +595,30 @@ namespace Lum {
 
         msg->input_window=dynamic_cast<X11::Window*>(window)->GetDrawable();
         msg->app_window=dynamic_cast<X11::Window*>(window)->GetDrawable();
-        msg->cmd=HILDON_IM_SETNSHOW;
+        msg->cmd=command;
         msg->trigger=triggerType;
 
-        if (XSendEvent(display->display,imWindow,False,NoEventMask,&event)==0) {
+        return XSendEvent(display->display,imWindow,False,NoEventMask,&event)!=0;
+      }
+
+      void Keyboard::ShowKeyboard()
+      {
+        //std::cout << "Keyboard::ShowKeyboard()" << std::endl;
+
+        if (!SendCommand(HILDON_IM_SETNSHOW)) {
           std::cerr << "Error while sending OpenKeyboard (_HILDON_IM_ACTIVATE)" << std::endl;
         }
-
-        XSync(display->display,false);
       }
 
-      void KeyboardManager::HideKeyboard()
+      void Keyboard::HideKeyboard()
       {
-        X11::Display *display=dynamic_cast<X11::Display*>(Lum::OS::display);
-
-        if (display==NULL) {
-          return;
-        }
-
-        ::Window imWindow=GetKeyboardWindow();
-
-        if (imWindow==None) {
-          return;
-        }
-
-        ::XEvent event;
-
-        memset(&event,0,sizeof(event));
-        event.xclient.type=ClientMessage;
-        event.xclient.window=imWindow;
-        event.xclient.message_type=XInternAtom(display->display,HILDON_IM_ACTIVATE_NAME,
-                                               false);
-        event.xclient.format=HILDON_IM_ACTIVATE_FORMAT;
-
-        HildonIMActivateMessage *msg = reinterpret_cast<HildonIMActivateMessage *>(&event.xclient.data);
-
-        msg->input_window=0;
-        msg->app_window=0;
-        msg->cmd=HILDON_IM_HIDE;
-        //msg->input_mode=HILDON_GTK_INPUT_MODE_FULL;
-        msg->trigger=triggerType;
-
-        if (XSendEvent(display->display,imWindow,False,NoEventMask,&event)==0) {
+        //std::cout << "Keyboard::HideKeyboard()" << std::endl;
+        if (!SendCommand(HILDON_IM_HIDE)) {
           std::cerr << "Error while sending 'CloseKeyboard' (_HILDON_IM_ACTIVATE)" << std::endl;
         }
-
-        XSync(display->display,false);
       }
 
-      ::Window KeyboardManager::GetKeyboardWindow() const
+      ::Window Keyboard::GetKeyboardWindow() const
       {
         X11::Display *display=dynamic_cast<X11::Display*>(Lum::OS::display);
 
@@ -615,7 +659,7 @@ namespace Lum {
         return window;
       }
 
-      void KeyboardManager::Cut()
+      void Keyboard::Cut()
       {
         Lum::Base::DataExchangeObject *object=OS::display->GetSelectionOwner();
 
@@ -637,7 +681,7 @@ namespace Lum {
         object->PostprocessAction(Lum::Base::DataExchangeObject::actionMove);
       }
 
-      void KeyboardManager::Copy()
+      void Keyboard::Copy()
       {
         Lum::Base::DataExchangeObject *object=OS::display->GetSelectionOwner();
 
@@ -657,7 +701,7 @@ namespace Lum {
         OS::display->SetClipboard(data.GetText());
       }
 
-      void KeyboardManager::Paste()
+      void Keyboard::Paste()
       {
         if (object==NULL) {
           return;
