@@ -569,8 +569,11 @@ namespace Lum {
           std::cerr << "Cannot activate advanved grafics mode: " << ::GetLastError() << std::endl;
         }
 
-        scrWidth=::GetSystemMetrics(SM_CXSCREEN);
-        scrHeight=::GetSystemMetrics(SM_CYSCREEN);
+        screenWidth=::GetSystemMetrics(SM_CXSCREEN);
+        screenHeight=::GetSystemMetrics(SM_CYSCREEN);
+
+        workAreaWidth=screenWidth;
+        workAreaHeight=screenHeight;
 
         type=typeGraphical;
 
@@ -587,6 +590,9 @@ namespace Lum {
         if (driver->GetDriverName()==L"Win32") {
           theme=new Win32Theme(this);
         }
+        else if (driver->GetDriverName()==L"CairoWin32") {
+          theme=new Win32Theme(this);
+        }
         else {
           theme=new OS::Base::DefaultTheme(this);
         }
