@@ -29,7 +29,7 @@
 #include <Lum/OS/Win32/Tray.h>
 
 #if defined(LUM_HAVE_LIB_CAIRO)
-  #include <Lum/OS/Cairo/Display.h>
+  #include <Lum/OS/Cairo/Driver.h>
   #include <Lum/OS/Cairo/DrawInfo.h>
 #endif
 
@@ -42,8 +42,7 @@ namespace Lum {
       LRESULT CALLBACK MessageHandler(HWND wnd, UINT msg, WPARAM wParam, LPARAM lParam)
       {
         Window *window;
-
-        /*
+/*
         std::cout << GetTickCount() << " " << wnd << " ";
         switch (msg) {
         case WM_CREATE:
@@ -592,14 +591,12 @@ namespace Lum {
       {
         RECT rect;
         
-        ::GetClientRect(window,&rect);
-        
         rect.left=x;
         rect.top=y;
         rect.right=x+width;
         rect.bottom=y+height;
         
-        ::InvalidateRect(window,&rect,true);
+        ::InvalidateRect(window,&rect,false);
       }
       
       bool Window::SendBalloonMessage(const std::wstring& /*text*/,
@@ -611,15 +608,20 @@ namespace Lum {
       void Window::OnPaint()
       {
         HDC          dc;
+        RECT         updateRect;
         PAINTSTRUCT  ps;
         OS::Bitmap   *bitmap=NULL;
         OS::DrawInfo *bitmapDraw=NULL;
         DrawMsg      msg;
-        
+
         if (IsShown() && !onOpened) {
           TriggerPreOpened();
         }
       
+        if (::GetUpdateRect(window,&updateRect,false)==0) {
+          return;
+        }
+      
         dc=::BeginPaint(window,&ps);
     
 #if defined(CAIRO_HAS_WIN32_SURFACE)
@@ -678,21 +680,22 @@ namespace Lum {
     
         /* ignore */ ::EndPaint(window,&ps);
 
-        if (IsShown() && !onOpened) {
-          TriggerOpened();
-        }
-        
         /*
           HACK: If we received focus before our window is
           drawn, send one focus message after first drawing
           the window
          */
         drawn=true;
+        
+        if (IsShown() && !onOpened) {
+          TriggerOpened();
+        }
 
         // See WM_SETFOCUS handling
-        if (queueFocus || grabWindow==this) {
-          TriggerFocusIn();
+        if (!HasFocus() &&
+            (queueFocus || grabWindow==this)) {
           queueFocus=false;
+          TriggerFocusIn();
         }
       }
       
@@ -704,12 +707,15 @@ namespace Lum {
         MINMAXINFO   *mmInfo;
 
         switch (msg) {
+        case WM_ERASEBKGND:
+          return 0;
         case WM_CLOSE:
           TriggerClosed();
           return 0;
         case WM_PAINT:
           OnPaint();
-          break;
+          //break;
+          return 0;
         case WM_SIZE:
           if (wParam==SIZE_MINIMIZED) {
             drawn=false;
