@@ -168,7 +168,8 @@ namespace Lum {
       void Window::Resync(Lum::Base::Model* model,
                           const Lum::Base::ResyncMsg& msg)
       {
-        if (model==checkRefreshAction && checkRefreshAction->IsFinished()) {
+        if (model==checkRefreshAction &&
+            checkRefreshAction->IsFinished()) {
           CheckRefresh();
         }
 
@@ -459,9 +460,11 @@ data        : POINTER TO ARRAY OF LONGINT;*/
 
           fullScreen=IsFullScreenInternal();
 
-          if ((size_t)x11Event.xconfigure.width!=width || (size_t)x11Event.xconfigure.height!=height) {
+          if ((size_t)x11Event.xconfigure.width!=width ||
+              (size_t)x11Event.xconfigure.height!=height) {
             width=x11Event.xconfigure.width;
             height=x11Event.xconfigure.height;
+
             draw->SetNewSize(width,height);
 
             TriggerResize(x11Event.xconfigure.width-x11Event.xconfigure.border_width,
@@ -610,7 +613,6 @@ data        : POINTER TO ARRAY OF LONGINT;*/
         case PropertyNotify:
           //std::cout << "Property " << x11Event.xproperty.atom << " has changed!" << std::endl;
           break;
-          break;
         default:
           break;
         }
@@ -713,13 +715,20 @@ data        : POINTER TO ARRAY OF LONGINT;*/
           return false;
         }
 
-        int x1=redrawRects.front().x;
-        int y1=redrawRects.front().y;
-        int x2=x1+redrawRects.front().width-1;
-        int y2=y1+redrawRects.front().height-1;
+        // We make a copy of the original redra wrectangles and
+        // clear the redrawRects list. This may we do not get disturbed
+        // if somebody adds a new rectangle while we are redrawing.
+        std::vector<Rectangle> rects(redrawRects);
 
-        for (std::vector<Rectangle>::const_iterator rect=redrawRects.begin();
-             rect!=redrawRects.end();
+        redrawRects.clear();
+
+        int x1=rects.front().x;
+        int y1=rects.front().y;
+        int x2=x1+rects.front().width-1;
+        int y2=y1+rects.front().height-1;
+
+        for (std::vector<Rectangle>::const_iterator rect=rects.begin();
+             rect!=rects.end();
              ++rect) {
           x1=std::min(x1,rect->x);
           y1=std::min(y1,rect->y);
@@ -729,8 +738,8 @@ data        : POINTER TO ARRAY OF LONGINT;*/
 
         DrawInfo* draw=RequestRefreshDrawInfo(x1,y1,x2-x1+1,y2-y1+1);
 
-        for (std::vector<Rectangle>::const_iterator rect=redrawRects.begin();
-             rect!=redrawRects.end();
+        for (std::vector<Rectangle>::const_iterator rect=rects.begin();
+             rect!=rects.end();
              ++rect) {
           // There seems to be a bug in the cairo version with hildon...
 #if !defined(LUM_HAVE_LIB_HILDON)
@@ -753,8 +762,6 @@ data        : POINTER TO ARRAY OF LONGINT;*/
 
         ReleaseRefreshDrawInfo(x1,y1,x2-x1+1,y2-y1+1);
 
-        redrawRects.clear();
-
         return true;
       }
 
@@ -764,9 +771,59 @@ data        : POINTER TO ARRAY OF LONGINT;*/
 
         if (window!=0) {
           XResizeWindow(display->display,window,width,height);
+          draw->SetNewSize(width,height);
         }
       }
 
+      void Window::SetSize(size_t width,
+                           size_t height)
+      {
+        Base::Window::SetSize(width,height);
+
+        if (IsOpen()) {
+          Resize(width,height);
+          draw->SetNewSize(width,height);
+        }
+      }
+
+      void Window::SetMinMaxSize(size_t minWidth,
+                                 size_t minHeight,
+                                 size_t maxWidth,
+                                 size_t maxHeight)
+      {
+        Base::Window::SetMinMaxSize(minWidth,minHeight,
+                                    maxWidth,maxHeight);
+
+        if (IsOpen()) {
+          XSizeHints *sHints;
+
+          sHints=XAllocSizeHints();
+
+          if (sHints!=NULL) {
+            sHints->min_width=GetMinWidth();
+            sHints->min_height=GetMinHeight();
+            sHints->width=GetWidth();
+            sHints->height=GetHeight();
+            sHints->max_width=GetMaxWidth();
+            sHints->max_height=GetMaxHeight();
+            sHints->flags=PMinSize | PSize | PMaxSize;
+
+            XSetWMProperties(display->display,
+                             window,
+                             NULL,
+                             NULL,
+                             NULL,
+                             0,
+                             sHints,
+                             NULL,
+                             NULL);
+
+            XFree(sHints);
+          }
+        }
+      }
+
+
       void Window::MouseGrabOn()
       {
         if (XGrabPointer(display->display,window,
@@ -1010,6 +1067,40 @@ data        : POINTER TO ARRAY OF LONGINT;*/
                                                   false),
                                                   stackCount);
         }
+
+        if (GetHasMenuHint()) {
+          display->SetIntegerProperty(this,
+                                      XInternAtom(display->display,
+                                                  "_HILDON_WM_WINDOW_MENU_INDICATOR",
+                                                  false),
+                                                  1);
+        }
+
+        if (GetScreenOrientationHint()==Window::screenOrientationPortraitSupported ||
+            GetScreenOrientationHint()==Window::screenOrientationBothSupported) {
+          display->SetCardinalProperty(this,
+                                       XInternAtom(display->display,
+                                                   "_HILDON_PORTRAIT_MODE_SUPPORT",
+                                                   false),
+                                                   1);
+        }
+        else {
+          display->SetCardinalProperty(this,
+                                       XInternAtom(display->display,
+                                                   "_HILDON_PORTRAIT_MODE_SUPPORT",
+                                                   false),
+                                                   0);
+        }
+
+        if (type==typeMain) {
+          if (GetScreenOrientationHint()==Window::screenOrientationPortraitSupported) {
+            display->SetCardinalProperty(this,
+                                         XInternAtom(display->display,
+                                                     "_HILDON_PORTRAIT_MODE_REQUEST",
+                                                     false),
+                                                     1);
+          }
+        }
    #endif
 #endif
         /*
