@@ -106,6 +106,7 @@ namespace Lum {
 
   Object::Object()
   : parent(NULL),
+    window(NULL),
     x(0),y(0),width(0),height(0),
     minWidth(0),minHeight(0),
     maxWidth(32000),maxHeight(32000),
@@ -128,7 +129,8 @@ namespace Lum {
     redrawOnMouseActive(false),
     inited(false),
     shortcutAlways(false),
-    window(NULL),menu(NULL),help(NULL),
+    menu(NULL),
+    help(NULL),
     label(NULL),
     labeling(NULL),
     controller(NULL)
@@ -530,26 +532,30 @@ namespace Lum {
     class SetWindowVisitor : public Visitor
     {
     public:
+      OS::Window *window;
+
       bool Visit(Object* object)
       {
-        if (object!=NULL) {
-          object->window=NULL;
-          return object->VisitChildren(*this,false);
-        }
-        else {
-          return false;
+        object->window=window;
+        if (!object->VisitChildren(*this,false)) {
+          // That should always work, nobody is allowed to deny this visitor!
+          assert(false);
         }
+
+        return true;
       }
     };
 
-    SetWindowVisitor v;
+    SetWindowVisitor visitor;
 
-    this->window=window;
-    VisitChildren(v,false);
+    visitor.window=window;
+
+    visitor.Visit(this);
   }
 
   /**
-    \return Returns the OS::Window this Object belongs to.
+    \return Returns the OS::Window this Object belongs to. A valid window is available
+    and will be returned after the call to CalcSize(), else NULL is returned.
   */
   OS::Window* Object::GetWindow() const
   {
@@ -557,11 +563,16 @@ namespace Lum {
       return window;
     }
     else if (parent!=NULL) {
-      window=parent->GetWindow();
-      return window;
+      const Object* o=this;
+
+      while (o->parent!=NULL) {
+        o=o->parent;
+      }
+
+      return o->GetWindow();
     }
     else {
-      return NULL;
+      return NULL; 
     }
   }
 
@@ -569,10 +580,9 @@ namespace Lum {
     Sets the parent object of this object.
 
     \note
-    Normaly the objects tries to get its windows and thus is draw info object
-    asking its parent. So be carefull to set a parent object for each object
-    use instantiate. Most time this is automatically handled by the container
-    object.
+    Normaly the objects tries to get its window asking its parent. So be
+    carefull to set a parent object for each object you instantiate.
+    Most time this is automatically handled by the container object.
 
     Since top level object cannot have a parent, you must explicitely set
     the window calling SetWindow().
@@ -582,15 +592,6 @@ namespace Lum {
     assert(this->parent==NULL || this->parent==parent);
 
     this->parent=parent;
-    window=NULL;
-  }
-
-  /**
-    Return the parent object (or NULL, if this object is root) in the object tree.
-    */
-  Object* Object::GetParent() const
-  {
-    return parent;
   }
 
   /**
@@ -658,10 +659,10 @@ namespace Lum {
     store the object within a private variable and will return it when
     Object::GetHelp gets called.
    */
-  void Object::SetHelp(OS::Window* window)
+  void Object::SetHelp(OS::Window* help)
   {
     delete this->help;
-    this->help=window;
+    this->help=help;
   }
 
   /**
@@ -677,7 +678,7 @@ namespace Lum {
     store  the object within a private variable and will return it when
     Object::GetMenu gets called.
   */
-  void Object::SetMenu(OS::Window* window)
+  void Object::SetMenu(OS::Window* menu)
   {
     if (this->menu!=NULL) {
       if (this->menu->GetMaster()!=NULL) {
@@ -688,7 +689,7 @@ namespace Lum {
       }
     }
 
-    this->menu=window;
+    this->menu=menu;
   }
 
   /**
@@ -800,6 +801,17 @@ namespace Lum {
     return requestsLabelFocus;
   }
 
+  /**
+    Return the object that should be focused, if the current object
+    requests a mouse event grab. The default implementation returns
+    the object itself.
+   */
+  Lum::Object* Object::GetMouseGrabFocusObject() const
+  {
+    // Hmm, I do not like this, but making the method non-const is also strange...
+    return const_cast<Lum::Object*>(this);
+  }
+
   /**
     Controls should call this method within their constructor, if they
     request a keyboard for input.
@@ -1070,7 +1082,7 @@ namespace Lum {
     Object             *res;
 
     if (object==this) {
-      // First we search for the first object in the list of children
+      // First we search for the first focusable object in the list of children
       first.object=NULL;
       VisitChildren(first,true);
 
@@ -1078,7 +1090,7 @@ namespace Lum {
         return first.object;
       }
 
-      // Delegate it to our parent
+      // No focusable object in the list of children, delegate it to our parent
       if (parent!=NULL) {
         return parent->GetFocusNext(this);
       }
@@ -1087,7 +1099,8 @@ namespace Lum {
       }
     }
     else {
-      // Search for the next object in our list of children
+      // Search for the next object after the given object
+      // in our list of children
       after.start=false;
       after.base=object;
       after.object=NULL;
@@ -1640,24 +1653,6 @@ namespace Lum {
     return PointIsIn(event.x,event.y);
   }
 
-  /**
-    Tells if the mouse pointer is currently ober the object.
-  */
-  bool Object::MouseIsIn() const
-  {
-    if(!visible) {
-      return false;
-    }
-
-    int x,y;
-
-    if (GetWindow()->GetMousePos(x,y)) {
-      return PointIsIn(x,y);
-    }
-
-    return false;
-  }
-
   /**
     This method gets called when the window thinks, that the
     object should show somekind of keyboardfocus. This will
@@ -1853,17 +1848,6 @@ namespace Lum {
       }
     };
 
-    if (!background.Valid() ||
-        (background.Valid() && background->transparentBorder)) {
-      assert(parent!=NULL);
-
-      parent->DrawBackground(draw,x,y,w,h);
-
-      if (!background.Valid()) {
-        return;
-      }
-    }
-
     assert(background.Valid());
 
     DrawVisitor visitor;
@@ -2040,6 +2024,8 @@ namespace Lum {
   void Object::Redraw()
   {
     if (visible) {
+      assert(GetWindow()!=NULL);
+
       GetWindow()->TriggerDraw(oX,oY,oWidth,oHeight);
     }
   }
@@ -2047,6 +2033,8 @@ namespace Lum {
   void Object::Redraw(int x, int y, size_t w, size_t h)
   {
     if (visible) {
+      assert(GetWindow()!=NULL);
+
       GetWindow()->TriggerDraw(x,y,w,h);
     }
   }
@@ -2158,7 +2146,7 @@ namespace Lum {
   {
     mouseActive=true;
 
-    if (visible && redrawOnMouseActive) {
+    if (redrawOnMouseActive) {
       Redraw();
     }
   }
@@ -2170,7 +2158,7 @@ namespace Lum {
   {
     mouseActive=false;
 
-    if (visible && redrawOnMouseActive) {
+    if (redrawOnMouseActive) {
       Redraw();
     }
   }
@@ -2468,7 +2456,9 @@ namespace Lum {
 
   bool List::VisitChildren(Visitor &visitor, bool /*onlyVisible*/)
   {
-    for (std::list<Object*>::iterator iter=list.begin(); iter!=list.end(); ++iter) {
+    for (std::list<Object*>::iterator iter=list.begin();
+         iter!=list.end();
+         ++iter) {
       if (!visitor.Visit(*iter)) {
         return false;
       }
@@ -2505,7 +2495,8 @@ namespace Lum {
 
   bool Component::VisitChildren(Visitor &visitor, bool onlyVisible)
   {
-    if (container!=NULL && !visitor.Visit(container)) {
+    if (container!=NULL &&
+        !visitor.Visit(container)) {
       return false;
     }
 
@@ -2568,7 +2559,8 @@ namespace Lum {
 
   bool ControlComponent::VisitChildren(Visitor &visitor, bool onlyVisible)
   {
-    if (container!=NULL && !visitor.Visit(container)) {
+    if (container!=NULL &&
+        !visitor.Visit(container)) {
       return false;
     }
 
