@@ -24,7 +24,9 @@
 namespace Lum {
 
   PopupControl::PopupControl(Control* control)
-  : control(control),button(new Button()),popupAction(new Model::Action())
+  : control(control),
+    button(new Button()),
+    popupAction(new Model::Action())
   {
     button->SetModel(popupAction);
     //button->SetType(Button::typeSmall);
