@@ -100,9 +100,10 @@ namespace Lum {
     Object::CalcSize();
   }
 
-  void Segment7::Draw(int x, int y, size_t w, size_t h)
+  void Segment7::Draw(OS::DrawInfo* draw,
+                      int x, int y, size_t w, size_t h)
   {
-    Object::Draw(x,y,w,h);
+    Object::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -110,7 +111,6 @@ namespace Lum {
 
     /* --- */
 
-    OS::DrawInfo        *draw=GetDrawInfo();
     int                 dx,dy,xp,yp;
     OS::DrawInfo::Point points[7];
 
