@@ -291,20 +291,8 @@ namespace Lum {
       if (dynamic_cast<Model::String*>(model)) {
         SetConverter(new Model::StringStringConverter());
       }
-      else if (dynamic_cast<Model::Int*>(model)) {
-        SetConverter(new Model::IntStringConverter());
-      }
-      else if (dynamic_cast<Model::UInt*>(model)) {
-        SetConverter(new Model::UIntStringConverter());
-      }
-      else if (dynamic_cast<Model::Long*>(model)) {
-        SetConverter(new Model::LongStringConverter());
-      }
-      else if (dynamic_cast<Model::ULong*>(model)) {
-        SetConverter(new Model::ULongStringConverter());
-      }
-      else if (dynamic_cast<Model::SizeT*>(model)) {
-        SetConverter(new Model::SizeTStringConverter());
+      else if (dynamic_cast<Model::Number*>(model)) {
+        SetConverter(new Model::NumberStringConverter());
       }
     }
 
@@ -1386,14 +1374,12 @@ namespace Lum {
     if (event.type==OS::MouseEvent::down &&
         PointIsIn(event) &&
         event.button==OS::MouseEvent::button1) {
-      OS::Window* window=GetWindow();
-
       if (GetShowClearButton() &&
           event.x>=this->x+(int)(this->width-1-OS::display->GetTheme()->GetStockImage(OS::Theme::imageClear)->GetWidth())) {
         ActionEraseAll();
       }
-      else if (window->IsDoubleClicked() &&
-               PointIsIn(window->GetLastButtonClickEvent())) {
+      else if (GetWindow()->IsDoubleClicked() &&
+               PointIsIn(GetWindow()->GetLastButtonClickEvent())) {
         SelectAll();
         Redraw();
       }
@@ -1424,7 +1410,7 @@ namespace Lum {
     else if (event.IsGrabEnd() &&
              event.type==OS::MouseEvent::up &&
              event.button==OS::MouseEvent::button1) {
-      if (!window->IsDoubleClicked()) {
+      if (!GetWindow()->IsDoubleClicked()) {
         size_t help=GetCursorPos(event.x);
 
         if (help>cursor) {
