@@ -27,6 +27,8 @@
 
 #include <Lum/Manager/Behaviour.h>
 
+#include <Lum/OS/Driver.h>
+
 #include <Lum/Table.h>
 
 namespace Lum {
@@ -68,7 +70,7 @@ namespace Lum {
   {
     return false;
   }
-
+  
   /**
     Return the cell under the given coordinates. Returns false if there is no
     cell at the given position.
@@ -111,15 +113,19 @@ namespace Lum {
   {
     size_t pos;
 
-    vAdjustment->MakeVisible(y*rowHeight-(rowHeight-1));
-    vAdjustment->MakeVisible(y*rowHeight);
+    if (vAdjustment->IsValid()) {
+      vAdjustment->MakeVisible(y*rowHeight-(rowHeight-1));
+      vAdjustment->MakeVisible(y*rowHeight);
+    }
 
     pos=0;
     for (size_t i=0; i<x-1; i++) {
       pos+=header->GetColumnWidth(i);
     }
 
-    hAdjustment->MakeVisible(pos);
+    if (hAdjustment->IsValid()) {
+      hAdjustment->MakeVisible(pos);
+    }
   }
 
   /**
@@ -189,7 +195,7 @@ namespace Lum {
     this->model=dynamic_cast<Model::Table*>(model);
 
     if (this->model.Valid())  {
-      vAdjustment->SetTop(1);
+      vAdjustment->Set(1,height,this->model->GetRows()*rowHeight);
 
       if (painter==NULL) {
         if (dynamic_cast<Model::StringTable*>(model)!=NULL) {
@@ -339,7 +345,13 @@ namespace Lum {
         this->model->GetRows()>0) {
       if (rowHeight!=0) {
         vAdjustment->SetStepSize(rowHeight);
-        vAdjustment->Set(1,height,this->model->GetRows()*rowHeight);
+
+        if (vAdjustment.Valid()) {
+          vAdjustment->SetDimension(height,this->model->GetRows()*rowHeight);
+        }
+        else {
+          vAdjustment->Set(1,height,this->model->GetRows()*rowHeight);
+        }
       }
       else {
         vAdjustment->SetInvalid();
@@ -425,30 +437,32 @@ namespace Lum {
 
     size_t start,end;
 
-    start=(line-1)*rowHeight;
-    end=line*rowHeight-1;
+    // In adjustment space, everything starts from 1
+    start=(line-1)*rowHeight+1;
+    end=start+rowHeight-1;
 
     // Is line visible at all?
 
-    if (end+1<vAdjustment->GetTop()) {
+    if (end<vAdjustment->GetTop()) {
       return false;
     }
 
-    if (start+1>vAdjustment->GetTop()+height-1) {
+    if (start>vAdjustment->GetTop()+height-1) {
       return false;
     }
 
     // From now on at least something must be visible
 
-    if (start<vAdjustment->GetTop()-1) {
-      start=vAdjustment->GetTop()-1;
+    if (start<vAdjustment->GetTop()) {
+      start=vAdjustment->GetTop();
     }
 
-    if (end>vAdjustment->GetTop()-1+height-1) {
-      end=vAdjustment->GetTop()-1+height-1;
+    if (end>vAdjustment->GetTop()+height-1) {
+      end=vAdjustment->GetTop()+height-1;
     }
 
-    ly=start+1-vAdjustment->GetTop()+y;
+    // Now back again to screen dimensions
+    ly=start-vAdjustment->GetTop()+y;
     lheight=end-start+1;
 
     return true;
@@ -603,19 +617,20 @@ namespace Lum {
     int    endPos;
 
     draw->PushClip(x,y+start,width,height);
+
     draw->PushFont(font);
     draw->focused=HasFocus();
 
     startLine=(vAdjustment->GetTop()-1+start)/rowHeight;
     endLine=(vAdjustment->GetTop()-1+start+height-1)/rowHeight;
 
-    startPos=startLine*rowHeight+1-vAdjustment->GetTop();
-    endPos=(endLine+1)*rowHeight+1-vAdjustment->GetTop()-1;
+    startPos=startLine*rowHeight-(vAdjustment->GetTop()-1);
+    endPos=startPos+(endLine-startLine+1)*rowHeight-1;
 
     startPos+=y;
     endPos+=y;
 
-    while (startPos<=endPos) {
+    for (size_t i=startLine; i<=endLine; i++) {
       DrawLine(draw,startPos,startLine+1);
       startPos+=rowHeight;
       startLine++;
@@ -720,7 +735,13 @@ namespace Lum {
       RecalcTableWidth();
 
       hAdjustment->SetStepSize(font->StringWidth(L"m"));
-      hAdjustment->SetDimension(width,tableWidth);
+
+      if (hAdjustment->IsValid()) {
+        hAdjustment->SetDimension(width,tableWidth);
+      }
+      else {
+        hAdjustment->Set(1,width,tableWidth);
+      }
     }
     else {
       hAdjustment->SetInvalid();
@@ -743,6 +764,10 @@ namespace Lum {
     if (refreshes>1) {
       fullRefresh=true;
     }
+
+    if (OS::driver->GetDriverName()==L"CairoWin32") {
+      fullRefresh=true;
+    }
     refreshes=0;
 
     if (!model.Valid() || model->GetRows()==0) {
@@ -776,7 +801,7 @@ namespace Lum {
     }
 
     if (!fullRefresh && top!=vAdjustment->GetTop()) {
-      size_t diff=std::max(top,vAdjustment->GetTop())-std::min(top,vAdjustment->GetTop());
+      unsigned long diff=std::max(top,vAdjustment->GetTop())-std::min(top,vAdjustment->GetTop());
 
       if (diff>=height) {
         DrawFull(draw);
@@ -1060,7 +1085,8 @@ namespace Lum {
       return false;
     }
 
-    if (event.type==OS::MouseEvent::down && PointIsIn(event)) {
+    if (event.type==OS::MouseEvent::down &&
+        PointIsIn(event)) {
       if (event.button==OS::MouseEvent::button1) {
         size_t xc,yc;
 
@@ -1173,7 +1199,7 @@ namespace Lum {
       if (model==this->model) {
         if (selection.Valid() &&
             selection->HasSelection()) {
-          selection->OnClear();
+          selection->Clear();
         }
 
         ResyncWithModel();
@@ -1250,5 +1276,4 @@ namespace Lum {
 
     return true;
   }
-}
-
+}
\ No newline at end of file
