@@ -95,9 +95,10 @@ namespace Lum {
     Control::CalcSize();
   }
 
-  void TextValue::Draw(int x, int y, size_t w, size_t h)
+  void TextValue::Draw(OS::DrawInfo* draw,
+                       int x, int y, size_t w, size_t h)
   {
-    Control::Draw(x,y,w,h);
+    Control::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -106,7 +107,6 @@ namespace Lum {
     /* --- */
 
     if (model.Valid() && !model->IsNull()) {
-      OS::DrawInfo        *draw=GetDrawInfo();
       Lum::OS::FontExtent extent;
 
       font->StringExtent(model->Get(),extent,style);
