@@ -88,15 +88,15 @@ namespace Lum {
     draw->disabled=true;
   }
 
-  void TimeView::Draw(int x, int y, size_t w, size_t h)
+  void TimeView::Draw(OS::DrawInfo* draw,
+                      int x, int y, size_t w, size_t h)
   {
-    Object::Draw(x,y,w,h);
+    Object::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
     }
 
-    OS::DrawInfo   *draw=GetDrawInfo();
     std::wstring   buffer;
     OS::FontRef    font=OS::display->GetFont();
     OS::FontExtent extent;
