@@ -112,7 +112,34 @@ namespace Lum {
     return selected;
   }
 
-  void Tree::UpdateDimensions()
+  void Tree::CalcSize()
+  {
+    colHeight=font->height+2*OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
+
+    width=1;
+    height=1;
+
+    /* Our minimal size is equal to the normal size */
+    minWidth=width;
+    minHeight=height;
+
+    /* We *must* call CalcSize of our superclass! */
+    Scrollable::CalcSize();
+  }
+
+  void Tree::GetDimension(size_t& width, size_t& height)
+  {
+    width=this->width;
+
+    if (model.Valid()) {
+      height=model->GetVisible();
+    }
+    else {
+      height=colHeight*this->height;
+    }
+  }
+
+  void Tree::Layout()
   {
     if (!model.Valid() || model->GetTop()==NULL) {
       hAdjustment->SetInvalid();
@@ -129,24 +156,10 @@ namespace Lum {
       //TODO: Set hAdjustment
       hAdjustment->SetDimension(width,width);
     }
+
+    Scrollable::Layout();
   }
 
-  void Tree::CalcSize()
-  {
-    colHeight=font->height+2*OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
-
-    width=1;
-    height=1;
-
-    /* Our minimal size is equal to the normal size */
-    minWidth=width;
-    minHeight=height;
-
-    /* We *must* call CalcSize of our superclass! */
-    Scrollable::CalcSize();
-  }
-
-
   bool Tree::GetClickedEntryPos(int y, size_t& pos)
   {
     assert(model.Valid());
@@ -178,7 +191,7 @@ namespace Lum {
         /* ignore */ model->GetVisibleItem(pos,item,offset);
 
         if (event.x>=x+(int)(offset*OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)) &&
-            event.x<=x+(int)(offset*OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject))+colHeight) {
+            event.x<=x+(int)(offset*OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject))+(int)colHeight) {
           if (item->HasChildren()) {
             if (item->IsExpanded()) {
               item->Collaps();
@@ -188,7 +201,8 @@ namespace Lum {
             }
           }
         }
-        else if (event.x>x+(int)(offset*OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject))+colHeight && event.x<x+width) {
+        else if (event.x>x+(int)(offset*OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject))+(int)colHeight &&
+                 event.x<(int)(x+width)) {
           if (item!=selected) {
             SetSelection(item);
           }
@@ -221,21 +235,25 @@ namespace Lum {
       switch (event.key) {
       case OS::keyLeft:
         if (selected!=NULL) {
-          if (selected->HasChildren() && selected->IsExpanded()) {
+          if (selected->HasChildren() &&
+              selected->IsExpanded()) {
             selected->Collaps();
           }
         }
         break;
       case OS::keyRight:
         if (selected!=NULL) {
-          if (selected->HasChildren() && !selected->IsExpanded()) {
+          if (selected->HasChildren() &&
+              !selected->IsExpanded()) {
             selected->Expand();
           }
         }
         break;
       case OS::keyUp:
         if (selected!=NULL) {
-          if (selected->GetPrevious()!=NULL && selected->GetPrevious()->HasChildren() && selected->GetPrevious()->IsExpanded()) {
+          if (selected->GetPrevious()!=NULL &&
+              selected->GetPrevious()->HasChildren() &&
+              selected->GetPrevious()->IsExpanded()) {
             SetSelection(selected->GetPrevious()->GetLastChild());
           }
           else if (selected->GetPrevious()!=NULL) {
@@ -248,13 +266,15 @@ namespace Lum {
         break;
       case OS::keyDown:
         if (selected!=NULL) {
-          if (selected->HasChildren() && selected->IsExpanded()) {
+          if (selected->HasChildren() &&
+              selected->IsExpanded()) {
             SetSelection(selected->GetFirstChild());
           }
           else if (selected->GetNext()!=NULL) {
             SetSelection(selected->GetNext());
           }
-          else if (selected->GetParent()!=NULL && selected->GetParent()->GetNext()!=NULL) {
+          else if (selected->GetParent()!=NULL &&
+                   selected->GetParent()->GetNext()!=NULL) {
             SetSelection(selected->GetParent()->GetNext());
           }
         }
@@ -333,9 +353,10 @@ namespace Lum {
     }
   }
 
-  void Tree::Draw(int x, int y, size_t w, size_t h)
+  void Tree::Draw(OS::DrawInfo* draw,
+                  int x, int y, size_t w, size_t h)
   {
-    Scrollable::Draw(x,y,w,h);
+    Scrollable::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -347,7 +368,6 @@ namespace Lum {
       return;
     }
 
-    OS::DrawInfo      *draw=GetDrawInfo();
     size_t            offset;
     Model::Tree::Item *item;
 
