@@ -101,13 +101,10 @@ namespace Lum {
 
   Window::KeyHandler::~KeyHandler()
   {
-    std::list<Shortcut*>::iterator iter;
-
-    iter=shortcuts.begin();
-    while (iter!=shortcuts.end()) {
+    for (std::list<Shortcut*>::iterator iter=shortcuts.begin();
+         iter!=shortcuts.end();
+         ++iter) {
       delete *iter;
-
-      ++iter;
     }
   }
 
@@ -116,11 +113,6 @@ namespace Lum {
     this->top=top;
   }
 
-  Lum::Object* Window::GetMain() const
-  {
-    return main;
-  }
-
   void Window::KeyHandler::SetFocus(Lum::Object* object)
   {
     Lum::Object* oldCurrent=current;
@@ -204,7 +196,7 @@ namespace Lum {
     if (current!=NULL ||
         Manager::Behaviour::Instance()->FocusObjectOnWindowFocusIn()) {
       if (current!=NULL &&
-          (current->HandlesClickFocus() || current->HandlesKeyFocus())) {
+          current->HandlesKeyFocus()) {
         if (OS::display->GetKeyboardManager()!=NULL) {
           OS::display->GetKeyboardManager()->OnFocusChange(window,current,current);
         }
@@ -298,6 +290,20 @@ namespace Lum {
     sCurrent=NULL;
   }
 
+  void Window::KeyHandler::Reset()
+  {
+    CancelCurrent();
+    current=NULL;
+
+    for (std::list<Shortcut*>::iterator iter=shortcuts.begin();
+         iter!=shortcuts.end();
+         ++iter) {
+      delete *iter;
+    }
+
+    shortcuts.clear();
+  }
+
   bool Window::KeyHandler::HandleEvent(OS::KeyEvent* event)
   {
     Shortcut *sc;
@@ -386,6 +392,8 @@ namespace Lum {
 
     window->SetMaster(this);
 
+    Observe(OS::display->GetScreenRotatedAction());
+
     Observe(window->GetUnmapedAction());
     Observe(window->GetFocusInAction());
     Observe(window->GetFocusOutAction());
@@ -409,9 +417,17 @@ namespace Lum {
     }
 
     delete main;
+    main=NULL;
     delete window;
+    window=NULL;
   }
 
+  Lum::Object* Window::GetMain() const
+  {
+    return main;
+  }
+
+
   OS::Window* Window::GetWindow() const
   {
     return window;
@@ -475,6 +491,13 @@ namespace Lum {
 
   void Window::EvaluateMouseActive()
   {
+    if (main==NULL ||
+        !IsOpen() ||
+        !IsShown()) {
+      mouseActive=NULL;
+      return;
+    }
+
     Lum::Object *newActive;
 
     if (!window->HasFocus()) {
@@ -505,6 +528,7 @@ namespace Lum {
   */
   void Window::SetMain(Lum::Object* object)
   {
+    delete main;
     main=object;
     keyHandler.SetTop(main);
   }
@@ -520,15 +544,42 @@ namespace Lum {
 
   void Window::ReinitWindow()
   {
+    mouseActive=NULL;
+    keyHandler.Reset();
+
+    delete main;
+    main=NULL;
+
+    PreInit();
     CalcSize();
 
-    window->Resize(main->GetOWidth(),main->GetOHeight());
-
-    if (IsShown() || IsOpen()) {
-      // This has to be tested
-      window->TriggerResize(main->GetOWidth(),main->GetOHeight());
+    if (window->GetWidth()>=main->GetOMinWidth() &&
+        window->GetWidth()<=main->GetOMaxWidth() &&
+        window->GetHeight()>=main->GetOMinHeight() &&
+        window->GetHeight()<=main->GetOMaxHeight()) {
+      // Current window size does fit size of new main
+      if (main->GetOWidth()!=window->GetWidth() ||
+          main->GetOHeight()!=window->GetHeight()) {
+        // we need to resize mai, to fit into the current window
+        window->TriggerResize(window->GetWidth(),window->GetHeight());
+        window->TriggerDraw(0,0,window->GetWidth(),window->GetHeight());
+      }
+      else if (IsShown() || IsOpen()) {
+        // we just excahnged the window contents, no need to resize the window
+        window->TriggerDraw(0,0,window->GetWidth(),window->GetHeight());
+      }
+    }
+    else {
+      // we need to resize the window to hold the new main, resize it to
+      // the new main default size
+      window->Resize(main->GetOWidth(),main->GetOHeight());
       window->TriggerDraw(0,0,window->GetWidth(),window->GetHeight());
     }
+
+    window->SetMinMaxSize(main->GetOMinWidth(),
+                          main->GetOMinHeight(),
+                          main->GetOMaxWidth(),
+                          main->GetOMaxHeight());
   }
 
   void Window::OnContextHelp()
@@ -617,6 +668,10 @@ namespace Lum {
 
   void Window::ObjectHides(Lum::Object* object)
   {
+    if (main==NULL) {
+      return;
+    }
+
     if (object==mouseActive) {
       mouseActive=NULL;
     }
@@ -642,7 +697,8 @@ namespace Lum {
       Lum::Object           *grab;
 
     public:
-      MouseEventVisitor(const OS::MouseEvent& event) : event(event)
+      MouseEventVisitor(const OS::MouseEvent& event)
+      : event(event)
       {
         // no code
       }
@@ -673,12 +729,9 @@ namespace Lum {
 
     visitor.grab=NULL;
 
-    if (main!=NULL && main->IsVisible()) {
-      main->VisitChildren(visitor,true);
-
-      if (visitor.grab==NULL && main->HandleMouseEvent(event)) {
-        visitor.grab=main;
-      }
+    if (main!=NULL &&
+        main->IsVisible()) {
+      visitor.Visit(main);
     }
 
     return visitor.grab;
@@ -698,7 +751,8 @@ namespace Lum {
         Mouse grabbing and/or synchronous subdialogs may lead to mouse
         and key event occuring after window has been hidden!
       */
-      if (!IsOpen() || !IsShown()) {
+      if (!IsOpen() ||
+          !IsShown()) {
         return false;
       }
 
@@ -754,6 +808,7 @@ namespace Lum {
         mouseGrabHunting=true;
         mouseEvent->SetGrabed(false);
         mouseGrab=HandleMouseEvent(*mouseEvent);
+
         if (mouseGrab!=NULL) {
           if (!mouseGrabHunting) {
             mouseGrab=NULL;
@@ -762,14 +817,18 @@ namespace Lum {
 
         mouseGrabHunting=false;
 
-        if (mouseGrab!=NULL &&
-            mouseGrab->HandlesClickFocus()) {
-          SetFocus(dynamic_cast<Lum::Object*>(mouseGrab));
+        if (mouseGrab!=NULL) {
+          Lum::Object* focusObject=mouseGrab->GetMouseGrabFocusObject();
+
+          if (focusObject!=NULL &&
+              focusObject->HandlesClickFocus()) {
+            SetFocus(focusObject);
+          }
         }
       }
       else if (mouseEvent->type==OS::MouseEvent::move) {
         // We need that (currently) to get menu strip selection working
-        // TODO: Try to atrivate this only if a OS mouse grab is active!?
+        // TODO: Try to activate this only if a OS mouse grab is active!?
         mouseEvent->SetGrabed(false);
         HandleMouseEvent(*mouseEvent);
       }
@@ -785,11 +844,18 @@ namespace Lum {
         return false;
       }
 
+      if (keyEvent->type==OS::KeyEvent::up &&
+          keyEvent->qualifier & OS::qualifierControl &&
+          keyEvent->key==38) {
+        ReinitWindow();
+      }
+
       keyHandler.HandleEvent(keyEvent);
     }
 
     // Current object that grabed the mouse is not visible anymore => kill the grab
-    if (mouseGrab!=NULL && !mouseGrab->IsVisible()) {
+    if (mouseGrab!=NULL &&
+        !mouseGrab->IsVisible()) {
       mouseGrab=NULL;
     }
 
@@ -907,7 +973,6 @@ namespace Lum {
     else if (model==window->GetEventAction() &&
              window->GetEventAction()->IsFinished()) {
       const OS::Window::EventMsg *eventMsg=dynamic_cast<const OS::Window::EventMsg*>(&msg);
-
       HandleEvent(eventMsg->event);
     }
     else if (model==menuAction &&
@@ -930,6 +995,15 @@ namespace Lum {
         mouseActive=NULL;
       }
     }
+    else if (model==OS::display->GetScreenRotatedAction() &&
+             OS::display->GetScreenRotatedAction()->IsFinished()) {
+      if (IsOpen() &&
+          IsShown()) {
+        if (GetWindow()->GetScreenOrientationHint()==OS::Window::screenOrientationBothSupported) {
+          ReinitWindow();
+        }
+      }
+    }
   }
 
   bool Window::IsOpen() const
