@@ -57,19 +57,21 @@ int main()
   while (!testcasesA[x].nativePath.empty()) {
     Lum::Base::Path path;
 
-    std::cout << "'" << Lum::Base::WStringToString(testcasesA[x].nativePath) << "'" << std::endl;
 
     path.SetNativePath(testcasesA[x].nativePath);
 
-    std::cout << "Dir:  '" << Lum::Base::WStringToString(path.GetDir()) << "' <-> '" << Lum::Base::WStringToString(testcasesA[x].dir) << "'" << std::endl;
-    std::cout << "Base: '" << Lum::Base::WStringToString(path.GetBaseName()) << "' <-> '" << Lum::Base::WStringToString(testcasesA[x].baseName) << "'" << std::endl;
-
     if (path.GetDir()!=testcasesA[x].dir) {
+      std::cerr << "'" << Lum::Base::WStringToString(testcasesA[x].nativePath) << "'" << std::endl;
+      std::cerr << "Dir:  '" << Lum::Base::WStringToString(path.GetDir()) << "' <-> '" << Lum::Base::WStringToString(testcasesA[x].dir) << "'" << std::endl;
+      std::cerr << "Base: '" << Lum::Base::WStringToString(path.GetBaseName()) << "' <-> '" << Lum::Base::WStringToString(testcasesA[x].baseName) << "'" << std::endl;
       std::cerr << "ERROR!" << std::endl;
       return 1;
     }
 
     if (path.GetBaseName()!=testcasesA[x].baseName) {
+      std::cerr << "'" << Lum::Base::WStringToString(testcasesA[x].nativePath) << "'" << std::endl;
+      std::cerr << "Dir:  '" << Lum::Base::WStringToString(path.GetDir()) << "' <-> '" << Lum::Base::WStringToString(testcasesA[x].dir) << "'" << std::endl;
+      std::cerr << "Base: '" << Lum::Base::WStringToString(path.GetBaseName()) << "' <-> '" << Lum::Base::WStringToString(testcasesA[x].baseName) << "'" << std::endl;
       std::cerr << "ERROR!" << std::endl;
       return 1;
     }
@@ -81,14 +83,13 @@ int main()
   while (!testcasesB[x].nativePath.empty()) {
     Lum::Base::Path path;
 
-    std::cout << "'" << Lum::Base::WStringToString(testcasesB[x].dir) << "' + '" << Lum::Base::WStringToString(testcasesB[x].baseName) << "'" << std::endl;
 
     path.SetNativeDir(testcasesB[x].dir);
     path.SetBaseName(testcasesB[x].baseName);
 
-    std::cout << "NativePath:  '" << Lum::Base::WStringToString(path.GetPath()) << "' <-> '" << Lum::Base::WStringToString(testcasesB[x].nativePath) << "'" << std::endl;
-
     if (path.GetPath()!=testcasesB[x].nativePath) {
+      std::cerr << "'" << Lum::Base::WStringToString(testcasesB[x].dir) << "' + '" << Lum::Base::WStringToString(testcasesB[x].baseName) << "'" << std::endl;
+      std::cerr << "NativePath:  '" << Lum::Base::WStringToString(path.GetPath()) << "' <-> '" << Lum::Base::WStringToString(testcasesB[x].nativePath) << "'" << std::endl;
       std::cerr << "ERROR!" << std::endl;
       return 1;
     }
